@@ -1,7 +1,7 @@
 // qjackctl.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,18 +19,18 @@
 
 *****************************************************************************/
 
-#include "qjackctlAbout.h"
+#include "qjackctl.h"
+
 #include "qjackctlSetup.h"
 #include "qjackctlMainForm.h"
 
-#include <QApplication>
 #include <QLibraryInfo>
 #include <QTranslator>
 #include <QLocale>
 
 #include <QSessionManager>
 
-#if QT_VERSION < 0x040500
+#if QT_VERSION < QT_VERSION_CHECK(4, 5, 0)
 namespace Qt {
 const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 }
@@ -49,81 +49,67 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 // Singleton application instance stuff (Qt/X11 only atm.)
 //
 
-#if QT_VERSION < 0x050000
-#if defined(Q_WS_X11)
-#define CONFIG_X11
-#endif
-#else
-#if defined(QT_X11EXTRAS_LIB)
-#define CONFIG_X11
-#endif
-#endif
-
-
-#ifdef CONFIG_X11
 #ifdef CONFIG_XUNIQUE
 
-#include <unistd.h> /* for gethostname() */
-
-#include <QX11Info>
-
-#include <X11/Xatom.h>
-#include <X11/Xlib.h>
-
 #define QJACKCTL_XUNIQUE "qjackctlApplication"
 
-#if QT_VERSION >= 0x050100
-
-#include <xcb/xcb.h>
-#include <xcb/xproto.h>
-
-#include <QAbstractNativeEventFilter>
-
-class qjackctlApplication;
-
-class qjackctlXcbEventFilter : public QAbstractNativeEventFilter
-{
-public:
-
-	// Constructor.
-	qjackctlXcbEventFilter(qjackctlApplication *pApp)
-		: QAbstractNativeEventFilter(), m_pApp(pApp) {}
-
-	// XCB event filter (virtual processor).
-	bool nativeEventFilter(const QByteArray& eventType, void *message, long *);
-
-private:
-
-	// Instance variable.
-	qjackctlApplication *m_pApp;
-};
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+#include <unistd.h> /* for gethostname() */
+#include <X11/Xatom.h>
+#include <X11/Xlib.h>
+#endif	// CONFIG_X11
+#else
+#include <QSharedMemory>
+#include <QLocalServer>
+#include <QLocalSocket>
+#include <QHostInfo>
 #endif
 
 #endif	// CONFIG_XUNIQUE
-#endif	// CONFIG_X11
 
 
-class qjackctlApplication : public QApplication
+// Constructor.
+qjackctlApplication::qjackctlApplication ( int& argc, char **argv )
+	: QApplication(argc, argv),
+		m_pQtTranslator(nullptr), m_pMyTranslator(nullptr), m_pWidget(nullptr)
 {
-public:
-
-	// Constructor.
-	qjackctlApplication(int& argc, char **argv) : QApplication(argc, argv),
-		m_pQtTranslator(0), m_pMyTranslator(0), m_pWidget(0)
-	{
-		// Load translation support.
-		QLocale loc;
-		if (loc.language() != QLocale::C) {
-			// Try own Qt translation...
-			m_pQtTranslator = new QTranslator(this);
-			QString sLocName = "qt_" + loc.name();
-			QString sLocPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
-			if (m_pQtTranslator->load(sLocName, sLocPath)) {
-				QApplication::installTranslator(m_pQtTranslator);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
+	QApplication::setApplicationName(QJACKCTL_TITLE);
+	QApplication::setApplicationDisplayName(QJACKCTL_TITLE);
+	//	QJACKCTL_TITLE " - " + QObject::tr(QJACKCTL_SUBTITLE));
+#endif
+	// Load translation support.
+	QLocale loc;
+	if (loc.language() != QLocale::C) {
+		// Try own Qt translation...
+		m_pQtTranslator = new QTranslator(this);
+		QString sLocName = "qt_" + loc.name();
+		QString sLocPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+		if (m_pQtTranslator->load(sLocName, sLocPath)) {
+			QApplication::installTranslator(m_pQtTranslator);
+		} else {
+			delete m_pQtTranslator;
+			m_pQtTranslator = 0;
+		#ifdef CONFIG_DEBUG
+			qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
+				loc.name().toUtf8().constData(),
+				sLocPath.toUtf8().constData(),
+				sLocName.toUtf8().constData());
+		#endif
+		}
+		// Try own application translation...
+		m_pMyTranslator = new QTranslator(this);
+		sLocName = "qjackctl_" + loc.name();
+		if (m_pMyTranslator->load(sLocName, sLocPath)) {
+			QApplication::installTranslator(m_pMyTranslator);
+		} else {
+			sLocPath = CONFIG_DATADIR "/qjackctl/translations";
+			if (m_pMyTranslator->load(sLocName, sLocPath)) {
+				QApplication::installTranslator(m_pMyTranslator);
 			} else {
-				delete m_pQtTranslator;
-				m_pQtTranslator = 0;
+				delete m_pMyTranslator;
+				m_pMyTranslator = 0;
 			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toUtf8().constData(),
@@ -131,85 +117,78 @@ public:
 					sLocName.toUtf8().constData());
 			#endif
 			}
-			// Try own application translation...
-			m_pMyTranslator = new QTranslator(this);
-			sLocName = "qjackctl_" + loc.name();
-			if (m_pMyTranslator->load(sLocName, sLocPath)) {
-				QApplication::installTranslator(m_pMyTranslator);
-			} else {
-				sLocPath = CONFIG_DATADIR "/qjackctl/translations";
-				if (m_pMyTranslator->load(sLocName, sLocPath)) {
-					QApplication::installTranslator(m_pMyTranslator);
-				} else {
-					delete m_pMyTranslator;
-					m_pMyTranslator = 0;
-				#ifdef CONFIG_DEBUG
-					qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
-						loc.name().toUtf8().constData(),
-						sLocPath.toUtf8().constData(),
-						sLocName.toUtf8().constData());
-				#endif
-				}
-			}
 		}
-	#ifdef CONFIG_X11
-	#ifdef CONFIG_XUNIQUE
-		m_pDisplay = NULL;
-		m_wOwner = None;
-	#if QT_VERSION >= 0x050100
-		m_pXcbEventFilter = new qjackctlXcbEventFilter(this);
-		installNativeEventFilter(m_pXcbEventFilter);
-	#endif
-	#endif	// CONFIG_XUNIQUE
-	#endif	// CONFIG_X11
 	}
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+	m_pDisplay = nullptr;
+	m_aUnique = 0;
+	m_wOwner = 0;
+#endif	// CONFIG_X11
+#else
+	m_pMemory = nullptr;
+	m_pServer = nullptr;
+#endif
+#endif	// CONFIG_XUNIQUE
+}
 
-	// Destructor.
-	~qjackctlApplication()
-	{
-	#ifdef CONFIG_X11
-	#ifdef CONFIG_XUNIQUE
-	#if QT_VERSION >= 0x050100
-		removeNativeEventFilter(m_pXcbEventFilter);
-		delete m_pXcbEventFilter;
-	#endif
-	#endif	// CONFIG_XUNIQUE
-	#endif	// CONFIG_X11
-		if (m_pMyTranslator) delete m_pMyTranslator;
-		if (m_pQtTranslator) delete m_pQtTranslator;
+
+// Destructor.
+qjackctlApplication::~qjackctlApplication (void)
+{
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+	if (m_pServer) {
+		m_pServer->close();
+		delete m_pServer;
+		m_pServer = nullptr;
 	}
-
-	// Main application widget accessors.
-	void setMainWidget(QWidget *pWidget)
-	{
-		m_pWidget = pWidget;
-	#ifdef CONFIG_X11
-	#ifdef CONFIG_XUNIQUE
-		m_wOwner = m_pWidget->winId();
-		if (m_pDisplay && m_wOwner) {
-			XGrabServer(m_pDisplay);
-			XSetSelectionOwner(m_pDisplay, m_aUnique, m_wOwner, CurrentTime);
-			XUngrabServer(m_pDisplay);
-		}
-	#endif	// CONFIG_XUNIQUE
-	#endif	// CONFIG_X11
+	if (m_pMemory) {
+		delete m_pMemory;
+		m_pMemory = nullptr;
 	}
+#endif
+#endif	// CONFIG_XUNIQUE
+	if (m_pMyTranslator) delete m_pMyTranslator;
+	if (m_pQtTranslator) delete m_pQtTranslator;
+}
 
-	QWidget *mainWidget() const { return m_pWidget; }
 
-	// Check if another instance is running,
-    // and raise its proper main widget...
-	bool setup(const QString& sServerName)
-	{
-	#ifdef CONFIG_X11
-	#ifdef CONFIG_XUNIQUE
-		m_pDisplay = QX11Info::display();
+// Main application widget accessors.
+void qjackctlApplication::setMainWidget ( QWidget *pWidget )
+{
+	m_pWidget = pWidget;
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+	m_wOwner = m_pWidget->winId();
+	if (m_pDisplay && m_wOwner) {
+		XGrabServer(m_pDisplay);
+		XSetSelectionOwner(m_pDisplay, m_aUnique, m_wOwner, CurrentTime);
+		XUngrabServer(m_pDisplay);
+	}
+#endif	// CONFIG_X11
+#endif
+#endif	// CONFIG_XUNIQUE
+}
+
+
+// Check if another instance is running,
+// and raise its proper main widget...
+bool qjackctlApplication::setup ( const QString& sServerName )
+{
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+	m_pDisplay = QX11Info::display();
+	if (m_pDisplay) {
 		QString sUnique = QJACKCTL_XUNIQUE;
 		if (sServerName.isEmpty()) {
 			const char *pszServerName = ::getenv("JACK_DEFAULT_SERVER");
-			if (pszServerName) {
+			if (pszServerName && ::strcmp("default", pszServerName)) {
 				sUnique += '_';
-				sUnique += pszServerName;
+				sUnique += QString::fromUtf8(pszServerName);
 			}
 		} else {
 			sUnique += '_';
@@ -260,105 +239,188 @@ public:
 			// Done.
 			return true;
 		}
-	#endif	// CONFIG_XUNIQUE
-	#endif	// CONFIG_X11
-		return false;
 	}
-
-#ifdef CONFIG_X11
-#ifdef CONFIG_XUNIQUE
-	void x11PropertyNotify(Window w)
-	{
-		if (m_pDisplay && m_pWidget && m_wOwner == w) {
-			// Always check whether our property-flag is still around...
-			Atom aType;
-			int iFormat = 0;
-			unsigned long iItems = 0;
-			unsigned long iAfter = 0;
-			unsigned char *pData = 0;
-			if (XGetWindowProperty(
-					m_pDisplay,
-					m_wOwner,
-					m_aUnique,
-					0, 1024,
-					false,
-					m_aUnique,
-					&aType,
-					&iFormat,
-					&iItems,
-					&iAfter,
-					&pData) == Success
-				&& aType == m_aUnique && iItems > 0 && iAfter == 0) {
-				// Avoid repeating it-self...
-				XDeleteProperty(m_pDisplay, m_wOwner, m_aUnique);
-				// Just make it always shows up fine...
-				m_pWidget->show();
-				m_pWidget->raise();
-				m_pWidget->activateWindow();
-				// FIXME: Do our best speciality, although it should be
-				// done iif configuration says so, we'll do it anyway!
-				qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-				if (pMainForm)
-					pMainForm->startJack();
-			}
-			// Free any left-overs...
-			if (iItems > 0 && pData)
-				XFree(pData);
+#endif	// CONFIG_X11
+	return false;
+#else
+	m_sUnique = QCoreApplication::applicationName();
+	if (!sServerName.isEmpty()) {
+		m_sUnique += '-';
+		m_sUnique += sServerName;
+	}
+	m_sUnique += '@';
+	m_sUnique += QHostInfo::localHostName();
+#ifdef Q_OS_UNIX
+	m_pMemory = new QSharedMemory(m_sUnique);
+	m_pMemory->attach();
+	delete m_pMemory;
+#endif
+	m_pMemory = new QSharedMemory(m_sUnique);
+	bool bServer = false;
+	const qint64 pid = QCoreApplication::applicationPid();
+	struct Data { qint64 pid; };
+	if (m_pMemory->create(sizeof(Data))) {
+		m_pMemory->lock();
+		Data *pData = static_cast<Data *> (m_pMemory->data());
+		if (pData) {
+			pData->pid = pid;
+			bServer = true;
+		}
+		m_pMemory->unlock();
+	}
+	else
+	if (m_pMemory->attach()) {
+		m_pMemory->lock(); // maybe not necessary?
+		Data *pData = static_cast<Data *> (m_pMemory->data());
+		if (pData)
+			bServer = (pData->pid == pid);
+		m_pMemory->unlock();
+	}
+	if (bServer) {
+		QLocalServer::removeServer(m_sUnique);
+		m_pServer = new QLocalServer();
+		m_pServer->setSocketOptions(QLocalServer::UserAccessOption);
+		m_pServer->listen(m_sUnique);
+		QObject::connect(m_pServer,
+			SIGNAL(newConnection()),
+			SLOT(newConnectionSlot()));
+	} else {
+		QLocalSocket socket;
+		socket.connectToServer(m_sUnique);
+		if (socket.state() == QLocalSocket::ConnectingState)
+			socket.waitForConnected(200);
+		if (socket.state() == QLocalSocket::ConnectedState) {
+			socket.write(QCoreApplication::arguments().join(' ').toUtf8());
+			socket.flush();
+			socket.waitForBytesWritten(200);
 		}
 	}
-#if QT_VERSION < 0x050000
-	bool x11EventFilter(XEvent *pEv)
-	{
-		if (pEv->type == PropertyNotify
-			&& pEv->xproperty.state == PropertyNewValue)
-			x11PropertyNotify(pEv->xproperty.window);
-		return QApplication::x11EventFilter(pEv);
-	}
+	return !bServer;
 #endif
-#endif	// CONFIG_XUNIQUE
-#endif	// CONFIG_X11
-
-private:
-
-	// Translation support.
-	QTranslator *m_pQtTranslator;
-	QTranslator *m_pMyTranslator;
-
-	// Instance variables.
-	QWidget *m_pWidget;
-
-#ifdef CONFIG_X11
-#ifdef CONFIG_XUNIQUE
-	Display *m_pDisplay;
-	Atom     m_aUnique;
-	Window   m_wOwner;
-#if QT_VERSION >= 0x050100
-	qjackctlXcbEventFilter *m_pXcbEventFilter;
-#endif
-#endif	// CONFIG_XUNIQUE
-#endif	// CONFIG_X11
-};
-
-
-#ifdef CONFIG_X11
-#ifdef CONFIG_XUNIQUE
-#if QT_VERSION >= 0x050100
-// XCB Event filter (virtual processor).
-bool qjackctlXcbEventFilter::nativeEventFilter (
-	const QByteArray& eventType, void *message, long * )
-{
-	if (eventType == "xcb_generic_event_t") {
-		xcb_property_notify_event_t *pEv
-			= static_cast<xcb_property_notify_event_t *> (message);
-		if ((pEv->response_type & ~0x80) == XCB_PROPERTY_NOTIFY
-			&& pEv->state == XCB_PROPERTY_NEW_VALUE)
-			m_pApp->x11PropertyNotify(pEv->window);
-	}
+#else
 	return false;
+#endif	// !CONFIG_XUNIQUE
 }
+
+
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+
+void qjackctlApplication::x11PropertyNotify ( Window w )
+{
+	if (m_pDisplay && m_pWidget && m_wOwner == w) {
+		// Always check whether our property-flag is still around...
+		Atom aType;
+		int iFormat = 0;
+		unsigned long iItems = 0;
+		unsigned long iAfter = 0;
+		unsigned char *pData = 0;
+		if (XGetWindowProperty(
+				m_pDisplay,
+				m_wOwner,
+				m_aUnique,
+				0, 1024,
+				false,
+				m_aUnique,
+				&aType,
+				&iFormat,
+				&iItems,
+				&iAfter,
+				&pData) == Success
+			&& aType == m_aUnique && iItems > 0 && iAfter == 0) {
+			// Avoid repeating it-self...
+			XDeleteProperty(m_pDisplay, m_wOwner, m_aUnique);
+			// Just make it always shows up fine...
+			m_pWidget->show();
+			m_pWidget->raise();
+			m_pWidget->activateWindow();
+			// FIXME: Do our best speciality, although it should be
+			// done iif configuration says so, we'll do it anyway!
+			qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+			if (pMainForm)
+				pMainForm->startJack();
+		}
+		// Free any left-overs...
+		if (iItems > 0 && pData)
+			XFree(pData);
+	}
+}
+
+bool qjackctlApplication::x11EventFilter ( XEvent *pEv )
+{
+	if (pEv->type == PropertyNotify
+		&& pEv->xproperty.state == PropertyNewValue)
+		x11PropertyNotify(pEv->xproperty.window);
+	return QApplication::x11EventFilter(pEv);
+}
+
+#endif	// CONFIG_X11
+#else
+
+// Local server conection slot.
+void qjackctlApplication::newConnectionSlot (void)
+{
+	QLocalSocket *pSocket = m_pServer->nextPendingConnection();
+	QObject::connect(pSocket,
+		SIGNAL(readyRead()),
+		SLOT(readyReadSlot()));
+}
+
+// Local server data-ready slot.
+void qjackctlApplication::readyReadSlot (void)
+{
+	QLocalSocket *pSocket = qobject_cast<QLocalSocket *> (sender());
+	if (pSocket) {
+		const qint64 nread = pSocket->bytesAvailable();
+		if (nread > 0) {
+			const QByteArray data = pSocket->read(nread);
+			// Just make it always shows up fine...
+			m_pWidget->hide();
+			m_pWidget->show();
+			m_pWidget->raise();
+			m_pWidget->activateWindow();
+			// FIXME: Do our best speciality, although it should be
+			// done iif configuration says so, we'll do it anyway!
+			qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+			if (pMainForm) {
+				// Parse the pass-through command line arguments...
+				const QStringList& args
+					= QString::fromUtf8(data).split(' ');
+				const int argc = args.count();
+				for (int i = 1; i < argc; ++i) {
+					QString sArg = args.at(i);
+					QString sVal;
+					const int iEqual = sArg.indexOf('=');
+					if (iEqual >= 0) {
+						sVal = sArg.right(sArg.length() - iEqual - 1);
+						sArg = sArg.left(iEqual);
+					}
+					else if (i < argc - 1)
+						sVal = args.at(i + 1);
+					if (sArg == "-s" || sArg == "--start") {
+						pMainForm->startJack();
+					}
+					else if (sArg == "-p" || sArg == "--preset") {
+						if (!sVal.isEmpty())
+							pMainForm->activatePreset(sVal);
+						if (iEqual < 0)
+							++i;
+					}
+					else if (sArg == "-a" || sArg == "--active-patchbay") {
+						if (!sVal.isEmpty())
+							pMainForm->activatePatchbay(sVal);
+						if (iEqual < 0)
+							++i;
+					}
+				}
+			}
+		}
+	}
+}
+
 #endif
 #endif	// CONFIG_XUNIQUE
-#endif	// CONFIG_X11
 
 
 //-------------------------------------------------------------------------
@@ -382,7 +444,7 @@ void stacktrace ( int signo )
 	char cmd[80];
 
 	// Reinstall default handler; prevent race conditions...
-	signal(signo, SIG_DFL);
+	::signal(signo, SIG_DFL);
 
 	static const char *shell  = "/bin/sh";
 	static const char *format = "gdb -q --batch --pid=%d"
@@ -398,7 +460,7 @@ void stacktrace ( int signo )
 
 	// Fork child...
 	if (pid == 0) {
-		execl(shell, shell, "-c", cmd, NULL);
+		execl(shell, shell, "-c", cmd, nullptr);
 		_exit(1);
 		return;
 	}
@@ -428,12 +490,15 @@ int main ( int argc, char **argv )
 	Q_INIT_RESOURCE(qjackctl);
 #ifdef CONFIG_STACKTRACE
 #if defined(__GNUC__) && defined(Q_OS_LINUX)
-	signal(SIGILL,  stacktrace);
-	signal(SIGFPE,  stacktrace);
-	signal(SIGSEGV, stacktrace);
-	signal(SIGABRT, stacktrace);
-	signal(SIGBUS,  stacktrace);
+	::signal(SIGILL,  stacktrace);
+	::signal(SIGFPE,  stacktrace);
+	::signal(SIGSEGV, stacktrace);
+	::signal(SIGABRT, stacktrace);
+	::signal(SIGBUS,  stacktrace);
 #endif
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+	QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
 	qjackctlApplication app(argc, argv);
 
@@ -447,10 +512,11 @@ int main ( int argc, char **argv )
 	// Check if we'll just start an external program...
 	if (!settings.sCmdLine.isEmpty()) {
 		jack_client_t *pJackClient
-			= jack_client_open("qjackctl-start", JackNoStartServer, NULL);
+			= jack_client_open("qjackctl-start", JackNoStartServer, nullptr);
 		if (pJackClient) {
 			jack_client_close(pJackClient);
-			int iExitStatus = ::system(settings.sCmdLine.toUtf8().constData());
+			const int iExitStatus
+				= ::system(settings.sCmdLine.toUtf8().constData());
 			app.quit();
 			return iExitStatus;
 		}
@@ -467,7 +533,7 @@ int main ( int argc, char **argv )
 	// Dark themes grayed/disabled color group fix...
 	QPalette pal(app.palette());
 	if (pal.base().color().value() < 0x7f) {
-	#if QT_VERSION >= 0x050000
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		const QColor& color = pal.window().color();
 		const int iGroups = int(QPalette::Active | QPalette::Inactive) + 1;
 		for (int i = 0; i < iGroups; ++i) {
