@@ -1,7 +1,7 @@
 // qjackctlMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
 
 #include <QProcess>
 #include <QDateTime>
+#include <QMenu>
 
 #include <QSessionManager>
 
@@ -48,6 +49,8 @@ class qjackctlSessionForm;
 class qjackctlConnectionsForm;
 class qjackctlPatchbayForm;
 class qjackctlPatchbayRack;
+class qjackctlGraphForm;
+class qjackctlGraphPort;
 class qjackctlPortItem;
 
 #ifdef CONFIG_SYSTEM_TRAY
@@ -79,7 +82,8 @@ public:
 
 	static qjackctlMainForm *getInstance();
 
-	bool setup(qjackctlSetup * pSetup);
+	bool setup(qjackctlSetup *pSetup);
+	qjackctlSetup *setup() const;
 
 	jack_client_t *jackClient() const;
 	snd_seq_t *alsaSeq() const;
@@ -102,6 +106,8 @@ public:
 
 	void refreshPatchbay();
 
+	void queryDisconnect(
+		qjackctlGraphPort *port1, qjackctlGraphPort *port2);
 	void queryDisconnect(
 		qjackctlPortItem *pOPort, qjackctlPortItem *pIPort, int iSocketType);
 
@@ -112,29 +118,39 @@ public:
 	void updateConnectionsIconSize();
 	void updateJackClientPortAlias();
 	void updateJackClientPortMetadata();
-	void updateBezierLines();
 	void updateDisplayEffect();
 	void updateTimeDisplayFonts();
 	void updateTimeDisplayToolTips();
-	void updateTimeFormat();
 	void updateAliases();
 	void updateButtons();
+#ifdef CONFIG_DBUS
+	void updateJackDBus();
+#endif
 #ifdef CONFIG_SYSTEM_TRAY
 	void updateSystemTray();
 #endif
 	void showDirtySettingsWarning();
 	void showDirtySetupWarning();
 
+	// Some settings that are special someway...
+	bool resetBuffSize(jack_nframes_t nframes);
+
 public slots:
 
 	void startJack();
 	void stopJack();
 	void toggleJack();
 
+	void showSetupForm();
+	void showAboutForm();
+
 	void resetXrunStats();
 
 	void commitData(QSessionManager& sm);
 
+	void activatePreset(const QString&);
+	void activatePatchbay(const QString&);
+
 protected slots:
 
 	void readStdout();
@@ -146,6 +162,7 @@ protected slots:
 	void jackStabilize();
 
 	void stdoutNotifySlot(int);
+	void sigtermNotifySlot(int);
 	void alsaNotifySlot(int);
 
 	void timerSlot();
@@ -162,9 +179,7 @@ protected slots:
 	void toggleSessionForm();
 	void toggleConnectionsForm();
 	void togglePatchbayForm();
-
-	void showSetupForm();
-	void showAboutForm();
+	void toggleGraphForm();
 
 	void transportRewind();
 	void transportBackward();
@@ -173,10 +188,7 @@ protected slots:
 	void transportStop();
 	void transportForward();
 
-	void contextMenu(const QPoint&);
-
 	void activatePresetsMenu(QAction *);
-	void activatePreset(const QString&);
 	void activatePreset(int);
 
 	void quitMainForm();
@@ -184,11 +196,12 @@ protected slots:
 protected:
 
 	bool queryClose();
+	bool queryClosePreset();
 
-	void closeEvent(QCloseEvent * pCloseEvent);
+	void closeEvent(QCloseEvent *pCloseEvent);
 	void customEvent(QEvent *pEvent);
 
-	void appendStdoutBuffer(const QString&);
+	void appendStdoutBuffer(const QString& sText);
 	void flushStdoutBuffer();
 
 	bool stdoutBlock(int fd, bool bBlock) const;
@@ -203,9 +216,9 @@ protected:
 	QString& detectXrun(QString& s);
 	void updateXrunStats(float fXrunLast);
 
-	void appendMessagesColor(const QString& s, const QString& c);
-	void appendMessagesText(const QString& s);
-	void appendMessagesError(const QString& s);
+	void appendMessagesColor(const QString& sText, const QString& sColor);
+	void appendMessagesText(const QString& sText);
+	void appendMessagesError(const QString& sText);
 
 	void updateXrunCount();
 
@@ -213,10 +226,13 @@ protected:
 	QString formatElapsedTime(int iStatusItem, const QTime& t, bool bElapsed) const;
 	void updateElapsedTimes();
 
+	void updateContextMenu();
+
 	void portNotifyEvent();
 	void xrunNotifyEvent();
 	void buffNotifyEvent();
 	void shutNotifyEvent();
+	void freeNotifyEvent();
 	void exitNotifyEvent();
 #ifdef CONFIG_JACK_METADATA
 	void propNotifyEvent();
@@ -236,11 +252,16 @@ protected:
 	void contextMenuEvent(QContextMenuEvent *);
 	void mousePressEvent(QMouseEvent *pMouseEvent);
 
+	void queryDisconnect(
+		const QString& sOClientName, const QString& sOPortName,
+		const QString& sIClientName, const QString& sIPortName,
+		int iSocketType);
+
 #ifdef CONFIG_DBUS
 
 	// D-BUS: Set/reset parameter values
 	// from current selected preset options.
-	void setDBusParameters();
+	void setDBusParameters(const qjackctlPreset& preset);
 
 	// D-BUS: Set parameter values (with reset option).
 	bool setDBusEngineParameter(
@@ -255,7 +276,11 @@ protected:
 	bool resetDBusDriverParameter(const QString& param);
 	bool resetDBusParameter(const QStringList& path);
 
-	// D-BUS: Set parameter values.
+	// D-BUS: Get preset options
+	// from current parameter values.
+	bool getDBusParameters(qjackctlPreset& preset);
+
+	// D-BUS: Get parameter values.
 	QVariant getDBusEngineParameter(const QString& param);
 	QVariant getDBusDriverParameter(const QString& param);
 	QVariant getDBusParameter(const QStringList& path);
@@ -283,7 +308,7 @@ private:
 	jack_client_t *m_pJackClient;
 	bool m_bJackDetach;
 	bool m_bJackShutdown;
-	bool m_bJackStopped;
+	bool m_bJackRestart;
 
 	snd_seq_t *m_pAlsaSeq;
 
@@ -292,7 +317,8 @@ private:
 	QDBusInterface *m_pDBusConfig;
 	qjackctlDBusLogWatcher *m_pDBusLogWatcher;
 	bool m_bDBusStarted;
-#endif	
+	bool m_bDBusDetach;
+#endif
 
 	int m_iStartDelay;
 	int m_iTimerDelay;
@@ -304,12 +330,13 @@ private:
 	int m_iStatusBlink;
 	int m_iStatusRefresh;
 	int m_iPatchbayRefresh;
-
+	
 #ifdef CONFIG_JACK_METADATA
 	int m_iJackPropertyChange;
 #endif
 
 	QSocketNotifier *m_pStdoutNotifier;
+	QSocketNotifier *m_pSigtermNotifier;
 	QSocketNotifier *m_pAlsaNotifier;
 
 	int   m_iXrunCallbacks;
@@ -327,6 +354,7 @@ private:
 	qjackctlSessionForm     *m_pSessionForm;
 	qjackctlConnectionsForm *m_pConnectionsForm;
 	qjackctlPatchbayForm    *m_pPatchbayForm;
+	qjackctlGraphForm       *m_pGraphForm;
 	qjackctlSetupForm       *m_pSetupForm;
 
 	qjackctlPatchbayRack *m_pPatchbayRack;
@@ -334,7 +362,6 @@ private:
 	qjackctlPreset m_preset;
 
 	QString m_sStdoutBuffer;
-	QString m_sTimeDashes;
 	QString m_sJackCmdLine;
 
 #ifdef CONFIG_SYSTEM_TRAY
@@ -347,6 +374,11 @@ private:
 
 	int m_iTransportPlay;
 
+	// Common context menu.
+	QMenu m_menu;
+
+	int m_iMenuRefresh;
+
 	// Kind-of singleton reference.
 	static qjackctlMainForm *g_pMainForm;
 };
