@@ -1,7 +1,7 @@
 // qjackctlPatchbayForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ qjackctlPatchbayForm::qjackctlPatchbayForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	m_pSetup = NULL;
+	m_pSetup = nullptr;
 
 	// Create the patchbay view object.
 	m_pPatchbay = new qjackctlPatchbay(m_ui.PatchbayView);
@@ -169,6 +169,7 @@ void qjackctlPatchbayForm::showEvent ( QShowEvent *pShowEvent )
 	QWidget::showEvent(pShowEvent);
 }
 
+
 // Notify our parent that we're closing.
 void qjackctlPatchbayForm::hideEvent ( QHideEvent *pHideEvent )
 {
@@ -179,9 +180,16 @@ void qjackctlPatchbayForm::hideEvent ( QHideEvent *pHideEvent )
 		pMainForm->stabilizeForm();
 }
 
+
 // Just about to notify main-window that we're closing.
 void qjackctlPatchbayForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
 {
+	if (m_pSetup) {
+		const QString& sPatchbayPath = patchbayPath();
+		if (!sPatchbayPath.isEmpty())
+			m_pSetup->sPatchbayPath = sPatchbayPath;
+	}
+
 	QWidget::hide();
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
@@ -282,7 +290,7 @@ void qjackctlPatchbayForm::stabilizeForm ( void )
 	}
 
 	// Take care that IT might be destroyed already...
-	if (m_ui.PatchbayView->binding() == NULL)
+	if (m_ui.PatchbayView->binding() == nullptr)
 		return;
 
 	bool bExpandAll = false;
@@ -550,7 +558,7 @@ void qjackctlPatchbayForm::toggleActivePatchbay (void)
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm) {
 		pMainForm->setActivePatchbay(
-			m_bActivePatchbay ? QString::null : m_sPatchbayPath);
+			m_bActivePatchbay ? QString() : m_sPatchbayPath);
 	}
 
 	// Need to force/refresh the patchbay list...
@@ -569,7 +577,7 @@ void qjackctlPatchbayForm::setRecentPatchbays ( const QStringList& patchbays )
 // Update patchbay MRU variables and widgets.
 void qjackctlPatchbayForm::updateRecentPatchbays (void)
 {
-	// TRye not to be reeentrant.
+	// Try not to be reeentrant.
 	if (m_iUpdate > 0)
 		return;
 
