@@ -1,7 +1,7 @@
 // qjackctlSessionForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -87,7 +87,7 @@ qjackctlSessionInfraClientItemEditor::qjackctlSessionInfraClientItemEditor (
 		m_pBrowseButton->setFixedWidth(18);
 		m_pBrowseButton->setText("...");
 	}
-	else m_pBrowseButton = NULL;
+	else m_pBrowseButton = nullptr;
 	m_pResetButton = new QToolButton(/*this*/);
 	m_pResetButton->setFixedWidth(18);
 	m_pResetButton->setText("x");
@@ -135,7 +135,7 @@ QString qjackctlSessionInfraClientItemEditor::text (void) const
 // Item command browser.
 void qjackctlSessionInfraClientItemEditor::browseSlot (void)
 {
-	bool bBlockSignals = m_pItemEdit->blockSignals(true);
+	const bool bBlockSignals = m_pItemEdit->blockSignals(true);
 	const QString& sCommand
 		= QFileDialog::getOpenFileName(parentWidget(), tr("Infra-command"));
 	if (!sCommand.isEmpty())
@@ -159,7 +159,7 @@ void qjackctlSessionInfraClientItemEditor::resetSlot (void)
 // Item text finish notification.
 void qjackctlSessionInfraClientItemEditor::finishSlot (void)
 {
-	bool bBlockSignals = m_pItemEdit->blockSignals(true);
+	const bool bBlockSignals = m_pItemEdit->blockSignals(true);
 	emit finishSignal();
 	m_index = QModelIndex();
 	m_sDefaultText.clear();
@@ -236,7 +236,7 @@ qjackctlSessionForm::qjackctlSessionForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	m_pSetup = NULL;
+	m_pSetup = nullptr;
 
 	// Common (sigleton) session object.
 	m_pSession = new qjackctlSession();
@@ -263,7 +263,7 @@ qjackctlSessionForm::qjackctlSessionForm (
 	// Session tree view...
 	QHeaderView *pHeader = m_ui.SessionTreeView->header();
 //	pHeader->setDefaultAlignment(Qt::AlignLeft);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::ResizeToContents);
 #else
 //	pHeader->setResizeMode(QHeaderView::ResizeToContents);
@@ -277,7 +277,7 @@ qjackctlSessionForm::qjackctlSessionForm (
 	// Infra-client list view...
 	pHeader = m_ui.InfraClientListView->header();
 //	pHeader->setDefaultAlignment(Qt::AlignLeft);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::ResizeToContents);
 #else
 //	pHeader->setResizeMode(QHeaderView::ResizeToContents);
@@ -369,7 +369,7 @@ bool qjackctlSessionForm::queryClose (void)
 		// Rebuild infra-clients list...
 		m_pSession->clearInfraClients();
 		qjackctlSession::InfraClientList& list = m_pSession->infra_clients();
-		int iItemCount = m_ui.InfraClientListView->topLevelItemCount();
+		const int iItemCount = m_ui.InfraClientListView->topLevelItemCount();
 		for (int i = 0; i < iItemCount; ++i) {
 			QTreeWidgetItem *pItem = m_ui.InfraClientListView->topLevelItem(i);
 			if (pItem) {
@@ -442,9 +442,15 @@ void qjackctlSessionForm::hideEvent ( QHideEvent *pHideEvent )
 		pMainForm->stabilizeForm();
 }
 
+
 // Just about to notify main-window that we're closing.
 void qjackctlSessionForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
 {
+	if (m_pSetup) {
+		m_pSetup->sessionDirs = sessionDirs();
+		m_pSetup->bSessionSaveVersion = isSaveSessionVersion();
+	}
+
 	QWidget::hide();
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
@@ -486,7 +492,7 @@ void qjackctlSessionForm::recentSession (void)
 {
 	QAction *pAction = qobject_cast<QAction *> (sender());
 	if (pAction) {
-		int i = pAction->data().toInt();
+		const int i = pAction->data().toInt();
 		if (i >= 0 && i < m_sessionDirs.count())
 			loadSessionDir(m_sessionDirs.at(i));
 	}
@@ -556,7 +562,7 @@ void qjackctlSessionForm::saveSessionVersion ( bool bOn )
 // Update the recent session list and menu.
 void qjackctlSessionForm::updateRecent ( const QString& sSessionDir )
 {
-	int i = m_sessionDirs.indexOf(sSessionDir);
+	const int i = m_sessionDirs.indexOf(sSessionDir);
 	if (i >= 0)
 		m_sessionDirs.removeAt(i);
 	m_sessionDirs.prepend(sSessionDir);
@@ -617,11 +623,11 @@ void qjackctlSessionForm::loadSessionDir ( const QString& sSessionDir )
 	}
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return;
 
 	pMainForm->appendMessages(
@@ -629,7 +635,7 @@ void qjackctlSessionForm::loadSessionDir ( const QString& sSessionDir )
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-	bool bLoadSession = m_pSession->load(sSessionDir);
+	const bool bLoadSession = m_pSession->load(sSessionDir);
 	if (bLoadSession)
 		updateRecent(sessionDir.absolutePath());
 
@@ -673,11 +679,11 @@ void qjackctlSessionForm::saveSessionDir (
 	}
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return;
 
 	pMainForm->appendMessages(
@@ -758,7 +764,7 @@ void qjackctlSessionForm::updateSessionView (void)
 		pTopLevelItem->setText(2, pClientItem->client_command);
 		QListIterator<qjackctlSession::PortItem *>
 			iterPort(pClientItem->ports);
-		QTreeWidgetItem *pChildItem = NULL;
+		QTreeWidgetItem *pChildItem = nullptr;
 		while (iterPort.hasNext()) {
 			qjackctlSession::PortItem *pPortItem = iterPort.next();
 			pChildItem = new QTreeWidgetItem(pTopLevelItem, pChildItem);
@@ -767,7 +773,7 @@ void qjackctlSessionForm::updateSessionView (void)
 			pChildItem->setText(0, pPortItem->port_name);
 			QListIterator<qjackctlSession::ConnectItem *>
 				iterConnect(pPortItem->connects);
-			QTreeWidgetItem *pLeafItem = NULL;
+			QTreeWidgetItem *pLeafItem = nullptr;
 			while (iterConnect.hasNext()) {
 				qjackctlSession::ConnectItem *pConnectItem = iterConnect.next();
 				pLeafItem = new QTreeWidgetItem(pChildItem, pLeafItem);
@@ -804,7 +810,7 @@ void qjackctlSessionForm::sessionViewContextMenu ( const QPoint& pos )
 	bool bEnabled = false;
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
-		bEnabled = (pMainForm->jackClient() != NULL);
+		bEnabled = (pMainForm->jackClient() != nullptr);
 
 	pAction = menu.addAction(QIcon(":/images/open1.png"),
 		tr("&Load..."), this, SLOT(loadSession()));
@@ -846,7 +852,7 @@ void qjackctlSessionForm::addInfraClient (void)
 
 	const QString& sNewInfraClient = tr("New Client");
 
-	QTreeWidgetItem *pItem = NULL;
+	QTreeWidgetItem *pItem = nullptr;
 
 	const QList<QTreeWidgetItem *>& items
 		= m_ui.InfraClientListView->findItems(sNewInfraClient, Qt::MatchExactly);
@@ -889,7 +895,7 @@ void qjackctlSessionForm::editInfraClientCommit (void)
 		const QString& sKey = pItem->text(0);
 		if (!sKey.isEmpty()) {
 			const QString& sValue = pItem->text(1);
-			qjackctlSession::InfraClientItem *pInfraClientItem = NULL;
+			qjackctlSession::InfraClientItem *pInfraClientItem = nullptr;
 			qjackctlSession::InfraClientList& list = m_pSession->infra_clients();
 			qjackctlSession::InfraClientList::Iterator iter	= list.find(sKey);
 			if (iter == list.end()) {
@@ -920,10 +926,10 @@ void qjackctlSessionForm::removeInfraClient (void)
 		const QString& sKey = pItem->text(0);
 		qjackctlSession::InfraClientList& list = m_pSession->infra_clients();
 		qjackctlSession::InfraClientList::Iterator iter	= list.find(sKey);
-		if (iter != list.end()) {
+		if (iter != list.end())
 			list.erase(iter);
-			updateInfraClients();
-		}
+		delete pItem;
+		updateInfraClients();
 	}
 }
 
@@ -937,8 +943,8 @@ void qjackctlSessionForm::selectInfraClient (void)
 
 	QTreeWidgetItem *pItem = m_ui.InfraClientListView->currentItem();
 	m_ui.AddInfraClientPushButton->setEnabled(true);
-	m_ui.EditInfraClientPushButton->setEnabled(pItem != NULL);
-	m_ui.RemoveInfraClientPushButton->setEnabled(pItem != NULL);
+	m_ui.EditInfraClientPushButton->setEnabled(pItem != nullptr);
+	m_ui.RemoveInfraClientPushButton->setEnabled(pItem != nullptr);
 }
 
 
@@ -949,14 +955,14 @@ void qjackctlSessionForm::updateInfraClients (void)
 	qDebug("qjackctlSessionForm::updateInfraClients()");
 #endif
 
-	int iOldItem = m_ui.InfraClientListView->indexOfTopLevelItem(
+	const int iOldItem = m_ui.InfraClientListView->indexOfTopLevelItem(
 		m_ui.InfraClientListView->currentItem());
 
 	m_ui.InfraClientListView->clear();
 
 	const QIcon iconClient(":/images/client1.png");
 
-	QTreeWidgetItem *pItem = NULL;
+	QTreeWidgetItem *pItem = nullptr;
 	qjackctlSession::InfraClientList& list = m_pSession->infra_clients();
 	qjackctlSession::InfraClientList::ConstIterator iter = list.constBegin();
 	const qjackctlSession::InfraClientList::ConstIterator& iter_end
@@ -991,10 +997,10 @@ void qjackctlSessionForm::infraClientContextMenu ( const QPoint& pos )
 //	pAction->setEnabled(true);
 	pAction = menu.addAction(QIcon(":/images/edit1.png"),
 		tr("&Edit"), this, SLOT(editInfraClient()));
-	pAction->setEnabled(pItem != NULL);
+	pAction->setEnabled(pItem != nullptr);
 	pAction = menu.addAction(QIcon(":/images/remove1.png"),
 		tr("Re&move"), this, SLOT(removeInfraClient()));
-	pAction->setEnabled(pItem != NULL);
+	pAction->setEnabled(pItem != nullptr);
 	menu.addSeparator();
 	pAction = menu.addAction(QIcon(":/images/refresh1.png"),
 		tr("Re&fresh"), this, SLOT(updateInfraClients()));
@@ -1028,7 +1034,7 @@ void qjackctlSessionForm::keyPressEvent ( QKeyEvent *pKeyEvent )
 #ifdef CONFIG_DEBUG_0
 	qDebug("qjackctlSessionForm::keyPressEvent(%d)", pKeyEvent->key());
 #endif
-	int iKey = pKeyEvent->key();
+	const int iKey = pKeyEvent->key();
 	switch (iKey) {
 	case Qt::Key_Escape:
 		close();
