@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,6 +30,9 @@
 #include <QTextStream>
 #include <QFileInfo>
 
+#include <QApplication>
+#include <QDesktopWidget>
+
 #ifdef CONFIG_JACK_VERSION
 #include <jack/jack.h>
 #endif
@@ -102,9 +105,7 @@ void qjackctlSetup::loadSetup (void)
 	bQueryDisconnect         = m_settings.value("/QueryDisconnect", true).toBool();
 	bMessagesLog             = m_settings.value("/MessagesLog", false).toBool();
 	sMessagesLogPath         = m_settings.value("/MessagesLogPath", "qjackctl.log").toString();
-	bBezierLines             = m_settings.value("/BezierLines", false).toBool();
 	iTimeDisplay             = m_settings.value("/TimeDisplay", 0).toInt();
-	iTimeFormat              = m_settings.value("/TimeFormat", 0).toInt();
 	sMessagesFont            = m_settings.value("/MessagesFont").toString();
 	bMessagesLimit           = m_settings.value("/MessagesLimit", true).toBool();
 	iMessagesLimitLines      = m_settings.value("/MessagesLimitLines", 1000).toInt();
@@ -118,13 +119,13 @@ void qjackctlSetup::loadSetup (void)
 	sConnectionsFont         = m_settings.value("/ConnectionsFont").toString();
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
 	bQueryShutdown           = m_settings.value("/QueryShutdown", true).toBool();
+	bQueryRestart            = m_settings.value("/QueryRestart", false).toBool();
 	bKeepOnTop               = m_settings.value("/KeepOnTop", false).toBool();
 	bSystemTray              = m_settings.value("/SystemTray", false).toBool();
 	bSystemTrayQueryClose    = m_settings.value("/SystemTrayQueryClose", true).toBool();
 	bStartMinimized          = m_settings.value("/StartMinimized", false).toBool();
 	bServerConfig            = m_settings.value("/ServerConfig", true).toBool();
 	sServerConfigName        = m_settings.value("/ServerConfigName", ".jackdrc").toString();
-	bServerConfigTemp        = m_settings.value("/ServerConfigTemp", false).toBool();
 	bAlsaSeqEnabled          = m_settings.value("/AlsaSeqEnabled", true).toBool();
 	bDBusEnabled             = m_settings.value("/DBusEnabled", false).toBool();
 	bJackDBusEnabled         = m_settings.value("/JackDBusEnabled", false).toBool();
@@ -134,6 +135,7 @@ void qjackctlSetup::loadSetup (void)
 	bRightButtons            = m_settings.value("/RightButtons", true).toBool();
 	bTransportButtons        = m_settings.value("/TransportButtons", true).toBool();
 	bTextLabels              = m_settings.value("/TextLabels", true).toBool();
+	bGraphButton             = m_settings.value("/GraphButton", true).toBool();
 	iBaseFontSize            = m_settings.value("/BaseFontSize", 0).toInt();
 	m_settings.endGroup();
 
@@ -215,9 +217,7 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/QueryDisconnect",         bQueryDisconnect);
 	m_settings.setValue("/MessagesLog",             bMessagesLog);
 	m_settings.setValue("/MessagesLogPath",         sMessagesLogPath);
-	m_settings.setValue("/BezierLines",             bBezierLines);
 	m_settings.setValue("/TimeDisplay",             iTimeDisplay);
-	m_settings.setValue("/TimeFormat",              iTimeFormat);
 	m_settings.setValue("/MessagesFont",            sMessagesFont);
 	m_settings.setValue("/MessagesLimit",           bMessagesLimit);
 	m_settings.setValue("/MessagesLimitLines",      iMessagesLimitLines);
@@ -231,13 +231,13 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/ConnectionsFont",         sConnectionsFont);
 	m_settings.setValue("/QueryClose",              bQueryClose);
 	m_settings.setValue("/QueryShutdown",           bQueryShutdown);
+	m_settings.setValue("/QueryRestart",            bQueryRestart);
 	m_settings.setValue("/KeepOnTop",               bKeepOnTop);
 	m_settings.setValue("/SystemTray",              bSystemTray);
 	m_settings.setValue("/SystemTrayQueryClose",    bSystemTrayQueryClose);
 	m_settings.setValue("/StartMinimized",          bStartMinimized);
 	m_settings.setValue("/ServerConfig",            bServerConfig);
 	m_settings.setValue("/ServerConfigName",        sServerConfigName);
-	m_settings.setValue("/ServerConfigTemp",        bServerConfigTemp);
 	m_settings.setValue("/AlsaSeqEnabled",          bAlsaSeqEnabled);
 	m_settings.setValue("/DBusEnabled",             bDBusEnabled);
 	m_settings.setValue("/JackDBusEnabled",         bJackDBusEnabled);
@@ -247,6 +247,7 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/RightButtons",            bRightButtons);
 	m_settings.setValue("/TransportButtons",        bTransportButtons);
 	m_settings.setValue("/TextLabels",              bTextLabels);
+	m_settings.setValue("/GraphButton",             bGraphButton);
 	m_settings.setValue("/BaseFontSize",            iBaseFontSize);
 	m_settings.endGroup();
 
@@ -289,8 +290,10 @@ void qjackctlSetup::saveSetup (void)
 //---------------------------------------------------------------------------
 // Aliases preset management methods.
 
-bool qjackctlSetup::loadAliases ( const QString& sPreset )
+bool qjackctlSetup::loadAliases (void)
 {
+	QString sPreset = sDefPreset;
+
 	QString sSuffix;
 	if (sPreset != sDefPresetName && !sPreset.isEmpty()) {
 		sSuffix = '/' + sPreset;
@@ -303,24 +306,29 @@ bool qjackctlSetup::loadAliases ( const QString& sPreset )
 	const QString sAliasesKey = "/Aliases" + sSuffix;
 	m_settings.beginGroup(sAliasesKey);
 	m_settings.beginGroup("/Jack");	// FIXME: Audio
-	aliasAudioOutputs.loadSettings(m_settings, "/Outputs");
-	aliasAudioInputs.loadSettings(m_settings, "/Inputs");
+	aliases.audioOutputs.loadSettings(m_settings, "/Outputs");
+	aliases.audioInputs.loadSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.beginGroup("/Midi");
-	aliasMidiOutputs.loadSettings(m_settings, "/Outputs");
-	aliasMidiInputs.loadSettings(m_settings, "/Inputs");
+	aliases.midiOutputs.loadSettings(m_settings, "/Outputs");
+	aliases.midiInputs.loadSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.beginGroup("/Alsa");
-	aliasAlsaOutputs.loadSettings(m_settings, "/Outputs");
-	aliasAlsaInputs.loadSettings(m_settings, "/Inputs");
+	aliases.alsaOutputs.loadSettings(m_settings, "/Outputs");
+	aliases.alsaInputs.loadSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.endGroup();
 
+	aliases.dirty = false;
+	aliases.key = sPreset;
+
 	return true;
 }
 
-bool qjackctlSetup::saveAliases ( const QString& sPreset )
+bool qjackctlSetup::saveAliases (void)
 {
+	const QString& sPreset = aliases.key;
+
 	QString sSuffix;
 	if (sPreset != sDefPresetName && !sPreset.isEmpty()) {
 		sSuffix = "/" + sPreset;
@@ -334,19 +342,21 @@ bool qjackctlSetup::saveAliases ( const QString& sPreset )
 	m_settings.remove(sAliasesKey);
 	m_settings.beginGroup(sAliasesKey);
 	m_settings.beginGroup("/Jack");	// FIXME: Audio
-	aliasAudioOutputs.saveSettings(m_settings, "/Outputs");
-	aliasAudioInputs.saveSettings(m_settings, "/Inputs");
+	aliases.audioOutputs.saveSettings(m_settings, "/Outputs");
+	aliases.audioInputs.saveSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.beginGroup("/Midi");
-	aliasMidiOutputs.saveSettings(m_settings, "/Outputs");
-	aliasMidiInputs.saveSettings(m_settings, "/Inputs");
+	aliases.midiOutputs.saveSettings(m_settings, "/Outputs");
+	aliases.midiInputs.saveSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.beginGroup("/Alsa");
-	aliasAlsaOutputs.saveSettings(m_settings, "/Outputs");
-	aliasAlsaInputs.saveSettings(m_settings, "/Inputs");
+	aliases.alsaOutputs.saveSettings(m_settings, "/Outputs");
+	aliases.alsaInputs.saveSettings(m_settings, "/Inputs");
 	m_settings.endGroup();
 	m_settings.endGroup();
 
+	aliases.dirty = false;
+
 	return true;
 }
 
@@ -377,7 +387,6 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	preset.bShorts      = m_settings.value("/Shorts", false).toBool();
 	preset.bNoMemLock   = m_settings.value("/NoMemLock", false).toBool();
 	preset.bUnlockMem   = m_settings.value("/UnlockMem", false).toBool();
-	preset.bHWMon       = m_settings.value("/HWMon", false).toBool();
 	preset.bHWMeter     = m_settings.value("/HWMeter", false).toBool();
 	preset.bIgnoreHW    = m_settings.value("/IgnoreHW", false).toBool();
 	preset.iPriority    = m_settings.value("/Priority", 0).toInt();
@@ -399,6 +408,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	preset.iInLatency   = m_settings.value("/InLatency", 0).toInt();
 	preset.iOutLatency  = m_settings.value("/OutLatency", 0).toInt();
 	preset.iStartDelay  = m_settings.value("/StartDelay", 2).toInt();
+	preset.bSync        = m_settings.value("/Sync", false).toBool();
 	preset.bVerbose     = m_settings.value("/Verbose", false).toBool();
 	preset.iPortMax     = m_settings.value("/PortMax", 256).toInt();
 	preset.sMidiDriver  = m_settings.value("/MidiDriver").toString();
@@ -434,7 +444,6 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
 	m_settings.setValue("/Shorts",      preset.bShorts);
 	m_settings.setValue("/NoMemLock",   preset.bNoMemLock);
 	m_settings.setValue("/UnlockMem",   preset.bUnlockMem);
-	m_settings.setValue("/HWMon",       preset.bHWMon);
 	m_settings.setValue("/HWMeter",     preset.bHWMeter);
 	m_settings.setValue("/IgnoreHW",    preset.bIgnoreHW);
 	m_settings.setValue("/Priority",    preset.iPriority);
@@ -456,6 +465,7 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
 	m_settings.setValue("/InLatency",   preset.iInLatency);
 	m_settings.setValue("/OutLatency",  preset.iOutLatency);
 	m_settings.setValue("/StartDelay",  preset.iStartDelay);
+	m_settings.setValue("/Sync",        preset.bSync);
 	m_settings.setValue("/Verbose",     preset.bVerbose);
 	m_settings.setValue("/PortMax",     preset.iPortMax);
 	m_settings.setValue("/MidiDriver",  preset.sMidiDriver);
@@ -516,21 +526,21 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 {
 	QTextStream out(stderr);
 	const QString sEol = "\n\n";
+	const int argc = args.count();
 	int iCmdArgs = 0;
-	int argc = args.count();
 
-	for (int i = 1; i < argc; i++) {
+	for (int i = 1; i < argc; ++i) {
 
 		if (iCmdArgs > 0) {
 			sCmdLine += ' ';
 			sCmdLine += args.at(i);
-			iCmdArgs++;
+			++iCmdArgs;
 			continue;
 		}
 
 		QString sArg = args.at(i);
-		QString sVal = QString::null;
-		int iEqual = sArg.indexOf('=');
+		QString sVal;
+		const int iEqual = sArg.indexOf('=');
 		if (iEqual >= 0) {
 			sVal = sArg.right(sArg.length() - iEqual - 1);
 			sArg = sArg.left(iEqual);
@@ -548,7 +558,7 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 			}
 			sDefPreset = sVal;
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-a" || sArg == "--active-patchbay") {
 			if (sVal.isNull()) {
@@ -558,7 +568,7 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 			bActivePatchbay = true;
 			sActivePatchbayPath = sVal;
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-n" || sArg == "--server-name") {
 			if (sVal.isNull()) {
@@ -567,7 +577,7 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 			}
 			sServerName = sVal;
 			if (iEqual < 0)
-				i++;
+				++i;
 		}
 		else if (sArg == "-h" || sArg == "--help") {
 			print_usage(args.at(0));
@@ -588,7 +598,7 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 		else if (sArg != "-T" && sArg != "-ndefault") {
 			// Here starts the optional command line...
 			sCmdLine += sArg;
-			iCmdArgs++;
+			++iCmdArgs;
 		}
 	}
 
@@ -714,11 +724,23 @@ void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	if (pWidget) {
 	//	if (bVisible) pWidget->show(); -- force initial exposure?
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-	#if QT_VERSION >= 0x050000
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		const QByteArray& geometry
 			= m_settings.value("/geometry").toByteArray();
-		if (!geometry.isEmpty())
+		if (geometry.isEmpty()) {
+			QWidget *pParent = pWidget->parentWidget();
+			if (pParent)
+				pParent = pParent->window();
+			if (pParent == nullptr)
+				pParent = QApplication::desktop();
+			if (pParent) {
+				QRect wrect(pWidget->geometry());
+				wrect.moveCenter(pParent->geometry().center());
+				pWidget->move(wrect.topLeft());
+			}
+		} else {
 			pWidget->restoreGeometry(geometry);
+		}
 	#else//--LOAD_OLD_GEOMETRY
 		QPoint wpos;
 		QSize  wsize;
@@ -751,7 +773,7 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-	#if QT_VERSION >= 0x050000
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		m_settings.setValue("/geometry", pWidget->saveGeometry());
 	#else//--SAVE_OLD_GEOMETRY
 		const QPoint& wpos  = pWidget->pos();
@@ -769,4 +791,3 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 
 
 // end of qjackctlSetup.cpp
-
