@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 #ifndef __qjackctlSetup_h
 #define __qjackctlSetup_h
 
-#include "qjackctlConnectAlias.h"
+#include "qjackctlAliases.h"
 
 #include <QStringList>
 
@@ -55,7 +55,6 @@ struct qjackctlPreset
 	bool    bShorts;
 	bool    bNoMemLock;
 	bool    bUnlockMem;
-	bool    bHWMon;
 	bool    bHWMeter;
 	bool    bIgnoreHW;
 	int     iPriority;
@@ -77,6 +76,7 @@ struct qjackctlPreset
 	int     iInLatency;
 	int     iOutLatency;
 	int     iStartDelay;
+	bool    bSync;
 	bool    bVerbose;
 	int     iPortMax;
 	QString sMidiDriver;
@@ -143,9 +143,7 @@ public:
 	bool    bQueryDisconnect;
 	bool    bMessagesLog;
 	QString sMessagesLogPath;
-	bool    bBezierLines;
 	int     iTimeDisplay;
-	int     iTimeFormat;
 	QString sMessagesFont;
 	bool    bMessagesLimit;
 	int     iMessagesLimitLines;
@@ -159,13 +157,13 @@ public:
 	QString sConnectionsFont;
 	bool    bQueryClose;
 	bool    bQueryShutdown;
+	bool    bQueryRestart;
 	bool    bKeepOnTop;
 	bool    bSystemTray;
 	bool    bSystemTrayQueryClose;
 	bool    bStartMinimized;
 	bool    bServerConfig;
 	QString sServerConfigName;
-	bool    bServerConfigTemp;
 	bool    bAlsaSeqEnabled;
 	bool    bDBusEnabled;
 	bool    bJackDBusEnabled;
@@ -175,6 +173,7 @@ public:
 	bool    bRightButtons;
 	bool    bTransportButtons;
 	bool    bTextLabels;
+	bool    bGraphButton;
 	int     iBaseFontSize;
 
 	// Defaults...
@@ -193,16 +192,12 @@ public:
 	bool bSessionSaveVersion;
 
 	// Aliases containers.
-	qjackctlConnectAlias aliasAudioOutputs;
-	qjackctlConnectAlias aliasAudioInputs;
-	qjackctlConnectAlias aliasMidiOutputs;
-	qjackctlConnectAlias aliasMidiInputs;
-	qjackctlConnectAlias aliasAlsaOutputs;
-	qjackctlConnectAlias aliasAlsaInputs;
+	qjackctlAliases aliases;
 
 	// Aliases preset management methods.
-	bool loadAliases(const QString& sPreset);
-	bool saveAliases(const QString& sPreset);
+	bool loadAliases();
+	bool saveAliases();
+
 	// Preset management methods.
 	bool loadPreset(qjackctlPreset& preset, const QString& sPreset);
 	bool savePreset(qjackctlPreset& preset, const QString& sPreset);
