@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -37,6 +37,10 @@
 
 #include <QButtonGroup>
 
+#ifdef CONFIG_SYSTEM_TRAY
+#include <QSystemTrayIcon>
+#endif
+
 #ifdef CONFIG_COREAUDIO
 #include <iostream>
 #include <cstring>
@@ -68,7 +72,7 @@ qjackctlSetupForm::qjackctlSetupForm (
 	m_ui.setupUi(this);
 
 	// No settings descriptor initially (the caller will set it).
-	m_pSetup = NULL;
+	m_pSetup = nullptr;
 
 	// Setup time-display radio-button group.
 	m_pTimeDisplayButtonGroup = new QButtonGroup(this);
@@ -80,6 +84,8 @@ qjackctlSetupForm::qjackctlSetupForm (
 
 	// Initialize dirty control state.
 	m_iDirtySetup = 0;
+	m_iDirtyPreset = 0;
+	m_iDirtyBuffSize = 0;
 	m_iDirtySettings = 0;
 	m_iDirtyOptions = 0;
 
@@ -101,11 +107,11 @@ qjackctlSetupForm::qjackctlSetupForm (
 	m_ui.MessagesLimitLinesComboBox->setValidator(
 		new QIntValidator(m_ui.MessagesLimitLinesComboBox));
 
-	m_ui.PresetComboBox->setCompleter(NULL);
+	m_ui.PresetComboBox->setCompleter(nullptr);
 
-	m_ui.ServerNameComboBox->setCompleter(NULL);
-	m_ui.ServerPrefixComboBox->setCompleter(NULL);
-	m_ui.ServerSuffixComboBox->setCompleter(NULL);
+	m_ui.ServerNameComboBox->setCompleter(nullptr);
+	m_ui.ServerPrefixComboBox->setCompleter(nullptr);
+	m_ui.ServerSuffixComboBox->setCompleter(nullptr);
 
 	// UI connections...
 
@@ -149,9 +155,6 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ShortsCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
-	QObject::connect(m_ui.HWMonCheckBox,
-		SIGNAL(stateChanged(int)),
-		SLOT(settingsChanged()));
 	QObject::connect(m_ui.HWMeterCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
@@ -161,6 +164,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.UnlockMemCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
+	QObject::connect(m_ui.SyncCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(settingsChanged()));
 	QObject::connect(m_ui.VerboseCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
@@ -169,7 +175,7 @@ qjackctlSetupForm::qjackctlSetupForm (
 		SLOT(settingsChanged()));
 	QObject::connect(m_ui.FramesComboBox,
 		SIGNAL(editTextChanged(const QString&)),
-		SLOT(settingsChanged()));
+		SLOT(buffSizeChanged()));
 	QObject::connect(m_ui.SampleRateComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(settingsChanged()));
@@ -321,12 +327,6 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ElapsedXrunRadioButton,
 		SIGNAL(toggled(bool)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.TimeFormatComboBox,
-		SIGNAL(activated(int)),
-		SLOT(optionsChanged()));
-	QObject::connect(m_ui.DisplayEffectCheckBox,
-		SIGNAL(toggled(bool)),
-		SLOT(toggleDisplayEffect(bool)));
 	QObject::connect(m_ui.DisplayBlinkCheckBox,
 		SIGNAL(toggled(bool)),
 		SLOT(optionsChanged()));
@@ -351,9 +351,6 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ConnectionsIconSizeComboBox,
 		SIGNAL(activated(int)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.BezierLinesCheckBox,
-		SIGNAL(stateChanged(int)),
-		SLOT(optionsChanged()));
 	QObject::connect(m_ui.AliasesEnabledCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -405,9 +402,6 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ServerConfigNameComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.ServerConfigTempCheckBox,
-		SIGNAL(stateChanged(int)),
-		SLOT(optionsChanged()));
 #ifdef CONFIG_ALSA_SEQ
 	QObject::connect(m_ui.AlsaSeqEnabledCheckBox,
 		SIGNAL(stateChanged(int)),
@@ -433,17 +427,24 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.TextLabelsCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.GraphButtonCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.BaseFontSizeComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
-
+#if 0
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(accepted()),
 		SLOT(accept()));
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(rejected()),
 		SLOT(reject()));
-
+#else
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(clicked(QAbstractButton *)),
+		SLOT(buttonClicked(QAbstractButton *)));
+#endif
 	// Try to restore old window positioning.
 	adjustSize();
 }
@@ -527,7 +528,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.MessagesLogCheckBox->setChecked(m_pSetup->bMessagesLog);
 	setComboBoxCurrentText(m_ui.MessagesLogPathComboBox,
 		m_pSetup->sMessagesLogPath);
-	m_ui.BezierLinesCheckBox->setChecked(m_pSetup->bBezierLines);
 
 	// Load some other defaults...
 	QRadioButton *pRadioButton
@@ -536,8 +536,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	if (pRadioButton)
 		pRadioButton->setChecked(true);
 
-	m_ui.TimeFormatComboBox->setCurrentIndex(m_pSetup->iTimeFormat);
-
 	// Load font chooser samples...
 	const QString sSansSerif = "Sans Serif";
 	QFont font;
@@ -578,7 +576,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 		font.family() + ' ' + QString::number(font.pointSize()));
 
 	// The main display shiny effect option.
-	m_ui.DisplayEffectCheckBox->setChecked(m_pSetup->bDisplayEffect);
 	m_ui.DisplayBlinkCheckBox->setChecked(m_pSetup->bDisplayBlink);
 	toggleDisplayEffect(m_pSetup->bDisplayEffect);
 
@@ -611,7 +608,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.ServerConfigCheckBox->setChecked(m_pSetup->bServerConfig);
 	setComboBoxCurrentText(m_ui.ServerConfigNameComboBox,
 		m_pSetup->sServerConfigName);
-	m_ui.ServerConfigTempCheckBox->setChecked(m_pSetup->bServerConfigTemp);
 	m_ui.AlsaSeqEnabledCheckBox->setChecked(m_pSetup->bAlsaSeqEnabled);
 	m_ui.DBusEnabledCheckBox->setChecked(m_pSetup->bDBusEnabled);
 	m_ui.JackDBusEnabledCheckBox->setChecked(m_pSetup->bJackDBusEnabled);
@@ -621,17 +617,25 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.RightButtonsCheckBox->setChecked(!m_pSetup->bRightButtons);
 	m_ui.TransportButtonsCheckBox->setChecked(!m_pSetup->bTransportButtons);
 	m_ui.TextLabelsCheckBox->setChecked(!m_pSetup->bTextLabels);
+	m_ui.GraphButtonCheckBox->setChecked(m_pSetup->bGraphButton);
 	if (m_pSetup->iBaseFontSize > 0)
 		m_ui.BaseFontSizeComboBox->setEditText(QString::number(m_pSetup->iBaseFontSize));
 	else
 		m_ui.BaseFontSizeComboBox->setCurrentIndex(0);
 
-#ifndef CONFIG_SYSTEM_TRAY
-	m_ui.SystemTrayCheckBox->setChecked(false);
-	m_ui.SystemTrayCheckBox->setEnabled(false);
-	m_ui.SystemTrayQueryCloseCheckBox->setChecked(false);
-	m_ui.SystemTrayQueryCloseCheckBox->setEnabled(false);
+#ifdef CONFIG_SYSTEM_TRAY
+	const bool bSystemTray = QSystemTrayIcon::isSystemTrayAvailable();
+#else
+	const bool bSystemTray = false;
 #endif
+	if (!bSystemTray) {
+		m_ui.SystemTrayCheckBox->setChecked(false);
+		m_ui.SystemTrayCheckBox->setEnabled(false);
+		m_ui.SystemTrayQueryCloseCheckBox->setChecked(false);
+		m_ui.SystemTrayQueryCloseCheckBox->setEnabled(false);
+		m_ui.StartMinimizedCheckBox->setChecked(false);
+		m_ui.StartMinimizedCheckBox->setEnabled(false);
+	}
 #ifndef CONFIG_JACK_MIDI
 	m_ui.MidiDriverComboBox->setCurrentIndex(0);
 	m_ui.MidiDriverTextLabel->setEnabled(false);
@@ -664,85 +668,71 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 }
 
 
-void qjackctlSetupForm::changePreset ( const QString& sPreset )
+// Set form widgets from preset values...
+void qjackctlSetupForm::setCurrentPreset ( const qjackctlPreset& preset )
 {
-	if (sPreset.isEmpty())
-		return;
-
-	// Load Settings...
-	qjackctlPreset preset;
-	if (m_pSetup->loadPreset(preset, sPreset)) {
-		setComboBoxCurrentText(m_ui.ServerPrefixComboBox, preset.sServerPrefix);
-		setComboBoxCurrentText(m_ui.ServerNameComboBox,
-			preset.sServerName.isEmpty()
+	setComboBoxCurrentText(m_ui.ServerPrefixComboBox,
+		preset.sServerPrefix);
+	setComboBoxCurrentText(m_ui.ServerNameComboBox,
+		preset.sServerName.isEmpty()
+		? m_pSetup->sDefPresetName
+		: preset.sServerName);
+	m_ui.RealtimeCheckBox->setChecked(preset.bRealtime);
+	m_ui.SoftModeCheckBox->setChecked(preset.bSoftMode);
+	m_ui.MonitorCheckBox->setChecked(preset.bMonitor);
+	m_ui.ShortsCheckBox->setChecked(preset.bShorts);
+	m_ui.NoMemLockCheckBox->setChecked(preset.bNoMemLock);
+	m_ui.UnlockMemCheckBox->setChecked(preset.bUnlockMem);
+	m_ui.HWMeterCheckBox->setChecked(preset.bHWMeter);
+	m_ui.IgnoreHWCheckBox->setChecked(preset.bIgnoreHW);
+	m_ui.PrioritySpinBox->setValue(preset.iPriority);
+	setComboBoxCurrentText(m_ui.FramesComboBox,
+		QString::number(preset.iFrames));
+	setComboBoxCurrentText(m_ui.SampleRateComboBox,
+		QString::number(preset.iSampleRate));
+	m_ui.PeriodsSpinBox->setValue(preset.iPeriods);
+	setComboBoxCurrentText(m_ui.WordLengthComboBox,
+		QString::number(preset.iWordLength));
+	setComboBoxCurrentText(m_ui.WaitComboBox,
+	QString::number(preset.iWait));
+	m_ui.ChanSpinBox->setValue(preset.iChan);
+	setComboBoxCurrentText(m_ui.DriverComboBox, preset.sDriver);
+	setComboBoxCurrentText(m_ui.InterfaceComboBox,
+		preset.sInterface.isEmpty()
 			? m_pSetup->sDefPresetName
-			: preset.sServerName);
-		m_ui.RealtimeCheckBox->setChecked(preset.bRealtime);
-		m_ui.SoftModeCheckBox->setChecked(preset.bSoftMode);
-		m_ui.MonitorCheckBox->setChecked(preset.bMonitor);
-		m_ui.ShortsCheckBox->setChecked(preset.bShorts);
-		m_ui.NoMemLockCheckBox->setChecked(preset.bNoMemLock);
-		m_ui.UnlockMemCheckBox->setChecked(preset.bUnlockMem);
-		m_ui.HWMonCheckBox->setChecked(preset.bHWMon);
-		m_ui.HWMeterCheckBox->setChecked(preset.bHWMeter);
-		m_ui.IgnoreHWCheckBox->setChecked(preset.bIgnoreHW);
-		m_ui.PrioritySpinBox->setValue(preset.iPriority);
-		setComboBoxCurrentText(m_ui.FramesComboBox,
-			QString::number(preset.iFrames));
-		setComboBoxCurrentText(m_ui.SampleRateComboBox,
-			QString::number(preset.iSampleRate));
-		m_ui.PeriodsSpinBox->setValue(preset.iPeriods);
-		setComboBoxCurrentText(m_ui.WordLengthComboBox,
-			QString::number(preset.iWordLength));
-		setComboBoxCurrentText(m_ui.WaitComboBox,
-		QString::number(preset.iWait));
-		m_ui.ChanSpinBox->setValue(preset.iChan);
-		setComboBoxCurrentText(m_ui.DriverComboBox, preset.sDriver);
-		setComboBoxCurrentText(m_ui.InterfaceComboBox,
-			preset.sInterface.isEmpty()
-				? m_pSetup->sDefPresetName
-				: preset.sInterface);
-		m_ui.AudioComboBox->setCurrentIndex(preset.iAudio);
-		m_ui.DitherComboBox->setCurrentIndex(preset.iDither);
-		setComboBoxCurrentText(m_ui.TimeoutComboBox,
-			QString::number(preset.iTimeout));
-		setComboBoxCurrentText(m_ui.InDeviceComboBox,
-			preset.sInDevice.isEmpty()
-				? m_pSetup->sDefPresetName
-				: preset.sInDevice);
-		setComboBoxCurrentText(m_ui.OutDeviceComboBox,
-			preset.sOutDevice.isEmpty()
-				? m_pSetup->sDefPresetName
-				: preset.sOutDevice);
-		m_ui.InChannelsSpinBox->setValue(preset.iInChannels);
-		m_ui.OutChannelsSpinBox->setValue(preset.iOutChannels);
-		m_ui.InLatencySpinBox->setValue(preset.iInLatency);
-		m_ui.OutLatencySpinBox->setValue(preset.iOutLatency);
-		m_ui.StartDelaySpinBox->setValue(preset.iStartDelay);
-		m_ui.VerboseCheckBox->setChecked(preset.bVerbose);
-		setComboBoxCurrentText(m_ui.PortMaxComboBox,
-			QString::number(preset.iPortMax));
+			: preset.sInterface);
+	m_ui.AudioComboBox->setCurrentIndex(preset.iAudio);
+	m_ui.DitherComboBox->setCurrentIndex(preset.iDither);
+	setComboBoxCurrentText(m_ui.TimeoutComboBox,
+		QString::number(preset.iTimeout));
+	setComboBoxCurrentText(m_ui.InDeviceComboBox,
+		preset.sInDevice.isEmpty()
+			? m_pSetup->sDefPresetName
+			: preset.sInDevice);
+	setComboBoxCurrentText(m_ui.OutDeviceComboBox,
+		preset.sOutDevice.isEmpty()
+			? m_pSetup->sDefPresetName
+			: preset.sOutDevice);
+	m_ui.InChannelsSpinBox->setValue(preset.iInChannels);
+	m_ui.OutChannelsSpinBox->setValue(preset.iOutChannels);
+	m_ui.InLatencySpinBox->setValue(preset.iInLatency);
+	m_ui.OutLatencySpinBox->setValue(preset.iOutLatency);
+	m_ui.StartDelaySpinBox->setValue(preset.iStartDelay);
+	m_ui.SyncCheckBox->setChecked(preset.bSync);
+	m_ui.VerboseCheckBox->setChecked(preset.bVerbose);
+	setComboBoxCurrentText(m_ui.PortMaxComboBox,
+		QString::number(preset.iPortMax));
 #ifdef CONFIG_JACK_MIDI
-		setComboBoxCurrentText(m_ui.MidiDriverComboBox,
-			preset.sMidiDriver);
+	setComboBoxCurrentText(m_ui.MidiDriverComboBox,
+		preset.sMidiDriver);
 #endif
-		setComboBoxCurrentText(m_ui.ServerSuffixComboBox, preset.sServerSuffix);
-		// Reset dirty flag.
-		m_iDirtySettings = 0;
-	}
-
-	// Set current preset name..
-	m_sPreset = sPreset;
+	setComboBoxCurrentText(m_ui.ServerSuffixComboBox, preset.sServerSuffix);
 }
 
 
-bool qjackctlSetupForm::savePreset ( const QString& sPreset )
+// Get preset values from form widgets...
+bool qjackctlSetupForm::getCurrentPreset ( qjackctlPreset& preset )
 {
-	if (sPreset.isEmpty())
-		return false;
-
-	// Unload settings.
-	qjackctlPreset preset;
 	preset.sServerPrefix = m_ui.ServerPrefixComboBox->currentText();
 	preset.sServerName  = m_ui.ServerNameComboBox->currentText();
 	preset.bRealtime    = m_ui.RealtimeCheckBox->isChecked();
@@ -751,7 +741,6 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 	preset.bShorts      = m_ui.ShortsCheckBox->isChecked();
 	preset.bNoMemLock   = m_ui.NoMemLockCheckBox->isChecked();
 	preset.bUnlockMem   = m_ui.UnlockMemCheckBox->isChecked();
-	preset.bHWMon       = m_ui.HWMonCheckBox->isChecked();
 	preset.bHWMeter     = m_ui.HWMeterCheckBox->isChecked();
 	preset.bIgnoreHW    = m_ui.IgnoreHWCheckBox->isChecked();
 	preset.iPriority    = m_ui.PrioritySpinBox->value();
@@ -773,6 +762,7 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 	preset.iInLatency   = m_ui.InLatencySpinBox->value();
 	preset.iOutLatency  = m_ui.OutLatencySpinBox->value();
 	preset.iStartDelay  = m_ui.StartDelaySpinBox->value();
+	preset.bSync        = m_ui.SyncCheckBox->isChecked();
 	preset.bVerbose     = m_ui.VerboseCheckBox->isChecked();
 	preset.iPortMax     = m_ui.PortMaxComboBox->currentText().toInt();
 #ifdef CONFIG_JACK_MIDI
@@ -787,7 +777,39 @@ bool qjackctlSetupForm::savePreset ( const QString& sPreset )
 		preset.sInDevice.clear();
 	if (preset.sOutDevice == m_pSetup->sDefPresetName)
 		preset.sOutDevice.clear();
-	m_pSetup->savePreset(preset, sPreset);
+
+	return true;
+}
+
+
+void qjackctlSetupForm::changePreset ( const QString& sPreset )
+{
+	if (sPreset.isEmpty())
+		return;
+
+	// Load settings...
+	qjackctlPreset preset;
+	if (m_pSetup->loadPreset(preset, sPreset)) {
+		setCurrentPreset(preset);
+		// Reset dirty flag?
+		m_iDirtySettings = 0;
+		++m_iDirtyPreset;
+	}
+
+	// Set current preset name..
+	m_sPreset = sPreset;
+}
+
+
+bool qjackctlSetupForm::savePreset ( const QString& sPreset )
+{
+	if (sPreset.isEmpty())
+		return false;
+
+	// Unload settings.
+	qjackctlPreset preset;
+	if (getCurrentPreset(preset))
+		m_pSetup->savePreset(preset, sPreset);
 
 	return true;
 }
@@ -813,15 +835,31 @@ void qjackctlSetupForm::resetPresets (void)
 }
 
 
+void qjackctlSetupForm::updateCurrentPreset ( const qjackctlPreset& preset )
+{
+	// Current preset changed for sure...
+	if (m_pSetup) {
+		++m_iDirtySetup;
+		setComboBoxCurrentText(m_ui.PresetComboBox, m_pSetup->sDefPreset);
+		setCurrentPreset(preset);
+		--m_iDirtySetup;
+		// Set current preset name..
+		m_sPreset = m_ui.PresetComboBox->currentText();
+		// Set dirty flag anyway...
+		++m_iDirtySettings;
+	}
+}
+
+
 void qjackctlSetupForm::updateCurrentPreset (void)
 {
-   // Have current preset changed anyhow?
-   if (m_pSetup && m_pSetup->sDefPreset != m_sPreset) {
-	   ++m_iDirtySetup;
-	   setComboBoxCurrentText(m_ui.PresetComboBox, m_pSetup->sDefPreset);
-	   changePreset(m_ui.PresetComboBox->currentText());
-	   --m_iDirtySetup;
-   }
+	// Have current preset changed anyhow?
+	if (m_pSetup && m_pSetup->sDefPreset != m_sPreset) {
+		++m_iDirtySetup;
+		setComboBoxCurrentText(m_ui.PresetComboBox, m_pSetup->sDefPreset);
+		changePreset(m_ui.PresetComboBox->currentText());
+		--m_iDirtySetup;
+	}
 }
 
 
@@ -832,7 +870,7 @@ void qjackctlSetupForm::changeCurrentPreset ( const QString& sPreset )
 
 	// Check if there's any pending changes...
 	if (m_iDirtySettings > 0 && !m_sPreset.isEmpty()) {
-		switch (QMessageBox::warning(this,
+		switch (QMessageBox::warning(isVisible() ? this : parentWidget(),
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some settings have been changed:\n\n"
 			"\"%1\"\n\nDo you want to save the changes?")
@@ -885,7 +923,7 @@ void qjackctlSetupForm::deleteCurrentPreset (void)
 	const QString sPreset = m_ui.PresetComboBox->currentText();
 
 	// Try to prompt user if he/she really wants this...
-	if (QMessageBox::warning(this,
+	if (QMessageBox::warning(isVisible() ? this : parentWidget(),
 		tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 		tr("Delete preset:\n\n"
 		"\"%1\"\n\nAre you sure?")
@@ -913,13 +951,13 @@ void qjackctlSetupForm::deleteCurrentPreset (void)
 
 void qjackctlSetupForm::computeLatency (void)
 {
-	float lat = 0.0;
-	int p = m_ui.FramesComboBox->currentText().toInt();
-	int r = m_ui.SampleRateComboBox->currentText().toInt();
-	int n = m_ui.PeriodsSpinBox->value();
+	const int p = m_ui.FramesComboBox->currentText().toInt();
+	const int r = m_ui.SampleRateComboBox->currentText().toInt();
+	const int n = m_ui.PeriodsSpinBox->value();
+	float lat = 0.0f;
 	if (r > 0)
-		lat = (float) (1000.0 * p * n) / (float) r;
-	if (lat > 0.0)
+		lat = float(1000.0f * p * n) / float(r);
+	if (lat > 0.0f)
 		m_ui.LatencyTextValue->setText(QString::number(lat, 'g', 3) + " " + tr("msec"));
 	else
 		m_ui.LatencyTextValue->setText(tr("n/a"));
@@ -928,17 +966,17 @@ void qjackctlSetupForm::computeLatency (void)
 
 void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 {
-	bool bSun        = (sDriver == "sun");
-	bool bOss        = (sDriver == "oss");
-	bool bAlsa       = (sDriver == "alsa");
-	bool bCoreaudio  = (sDriver == "coreaudio");
-	bool bPortaudio  = (sDriver == "portaudio");
-	bool bFreebob    = (sDriver == "freebob");
-	bool bFirewire   = (sDriver == "firewire");
-	bool bNet        = (sDriver == "net" || sDriver == "netone");
+	const bool bSun        = (sDriver == "sun");
+	const bool bOss        = (sDriver == "oss");
+	const bool bAlsa       = (sDriver == "alsa");
+	const bool bCoreaudio  = (sDriver == "coreaudio");
+	const bool bPortaudio  = (sDriver == "portaudio");
+	const bool bFirewire   = (sDriver == "firewire");
+	const bool bNet        = (sDriver == "net" || sDriver == "netone");
+
 	bool bInEnabled  = false;
 	bool bOutEnabled = false;
-	bool bEnabled;
+	bool bEnabled    = false;;
 
 	switch (iAudio) {
 	case QJACKCTL_DUPLEX:
@@ -972,11 +1010,11 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
 	m_ui.InOutLatencyTextLabel->setEnabled((bInEnabled && !bNet)
-		|| (bAlsa || bFreebob || bFirewire));
+		|| (bAlsa || bFirewire));
 	m_ui.InLatencySpinBox->setEnabled((bInEnabled && !bNet)
-		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
+		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
 	m_ui.OutLatencySpinBox->setEnabled((bOutEnabled && !bNet)
-		|| ((bAlsa || bFreebob || bFirewire) && iAudio != QJACKCTL_CAPTURE));
+		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
 	computeLatency();
 }
@@ -996,33 +1034,39 @@ void qjackctlSetupForm::changeDriver ( int iDriver )
 
 void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdate )
 {
-	bool bDummy     = (sDriver == "dummy");
-	bool bSun       = (sDriver == "sun");
-	bool bOss       = (sDriver == "oss");
-	bool bAlsa      = (sDriver == "alsa");
-	bool bPortaudio = (sDriver == "portaudio");
-	bool bCoreaudio = (sDriver == "coreaudio");
-	bool bFreebob   = (sDriver == "freebob");
-	bool bFirewire  = (sDriver == "firewire");
-	bool bNet       = (sDriver == "net" || sDriver == "netone");
+	const bool bDummy     = (sDriver == "dummy");
+	const bool bSun       = (sDriver == "sun");
+	const bool bOss       = (sDriver == "oss");
+	const bool bAlsa      = (sDriver == "alsa");
+	const bool bPortaudio = (sDriver == "portaudio");
+	const bool bCoreaudio = (sDriver == "coreaudio");
+	const bool bFirewire  = (sDriver == "firewire");
+	const bool bNet       = (sDriver == "net" || sDriver == "netone");
 
-	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio);
-	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio
+#ifdef CONFIG_DBUS
+	const bool bJackDBus  = m_ui.JackDBusEnabledCheckBox->isChecked();
+#else
+	const bool bJackDBus  = false;
+#endif
+
+	m_ui.SyncCheckBox->setEnabled(bJackDBus);
+
+	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio && !bJackDBus);
+	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio && !bJackDBus
 		&& !m_ui.NoMemLockCheckBox->isChecked());
 
 	m_ui.SoftModeCheckBox->setEnabled(bAlsa);
 	m_ui.MonitorCheckBox->setEnabled(bAlsa);
 	m_ui.ShortsCheckBox->setEnabled(bAlsa);
-	m_ui.HWMonCheckBox->setEnabled(bAlsa);
 	m_ui.HWMeterCheckBox->setEnabled(bAlsa);
 
-	m_ui.IgnoreHWCheckBox->setEnabled(bSun || bOss);
+	m_ui.IgnoreHWCheckBox->setEnabled((bSun || bOss) && !bJackDBus);
 
 	if (bCoreaudio || bPortaudio) {
 		m_ui.PriorityTextLabel->setEnabled(false);
 		m_ui.PrioritySpinBox->setEnabled(false);
 	} else {
-		bool bPriorityEnabled = m_ui.RealtimeCheckBox->isChecked();
+		const bool bPriorityEnabled = m_ui.RealtimeCheckBox->isChecked();
 		m_ui.PriorityTextLabel->setEnabled(bPriorityEnabled);
 		m_ui.PrioritySpinBox->setEnabled(bPriorityEnabled);
 	}
@@ -1033,14 +1077,14 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.FramesTextLabel->setEnabled(!bNet);
 	m_ui.FramesComboBox->setEnabled(!bNet);
 	
-	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
-	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
+	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFirewire);
+	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFirewire);
 
-	if (bUpdate && (bFreebob || bFirewire) && m_ui.PeriodsSpinBox->value() < 3)
+	if (bUpdate && (bFirewire) && m_ui.PeriodsSpinBox->value() < 3)
 		m_ui.PeriodsSpinBox->setValue(3);
 
-	m_ui.WordLengthTextLabel->setEnabled(bSun || bOss);
-	m_ui.WordLengthComboBox->setEnabled(bSun || bOss);
+	m_ui.WordLengthTextLabel->setEnabled((bSun || bOss) && !bJackDBus);
+	m_ui.WordLengthComboBox->setEnabled((bSun || bOss) && !bJackDBus);
 
 	m_ui.WaitTextLabel->setEnabled(bDummy);
 	m_ui.WaitComboBox->setEnabled(bDummy);
@@ -1048,7 +1092,8 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.ChanTextLabel->setEnabled(bPortaudio);
 	m_ui.ChanSpinBox->setEnabled(bPortaudio);
 
-	int  iAudio   = m_ui.AudioComboBox->currentIndex();
+	const int iAudio
+		= m_ui.AudioComboBox->currentIndex();
 	bool bEnabled = (bAlsa || bPortaudio);
 	if (bEnabled && iAudio == QJACKCTL_DUPLEX) {
 		const QString& sInDevice  = m_ui.InDeviceComboBox->currentText();
@@ -1057,7 +1102,7 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 					sOutDevice.isEmpty() || sOutDevice == m_pSetup->sDefPresetName);
 	}
 
-	bool bInterface = (bEnabled || bCoreaudio || bFreebob || bFirewire);
+	const bool bInterface = (bEnabled || bCoreaudio || bFirewire);
 	m_ui.InterfaceTextLabel->setEnabled(bInterface);
 	m_ui.InterfaceComboBox->setEnabled(bInterface);
 	if (!bInterface)
@@ -1071,6 +1116,13 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.MidiDriverComboBox->setEnabled(bAlsa);
 #endif
 
+	m_ui.ServerNameTextLabel->setEnabled(!bJackDBus);
+	m_ui.ServerNameComboBox->setEnabled(!bJackDBus);
+	m_ui.ServerPrefixTextLabel->setEnabled(!bJackDBus);
+	m_ui.ServerPrefixComboBox->setEnabled(!bJackDBus);
+	m_ui.ServerSuffixTextLabel->setEnabled(!bJackDBus);
+	m_ui.ServerSuffixComboBox->setEnabled(!bJackDBus);
+
 	changeDriverAudio(sDriver, iAudio);
 }
 
@@ -1160,9 +1212,11 @@ void qjackctlSetupForm::stabilizeForm (void)
 		m_ui.StopJackCheckBox->setChecked(true);
 	}
 
-	bEnabled = m_ui.ServerConfigCheckBox->isChecked();
+	bEnabled = !m_ui.JackDBusEnabledCheckBox->isChecked();
+	m_ui.ServerConfigCheckBox->setEnabled(bEnabled);
+	if (bEnabled)
+		bEnabled = m_ui.ServerConfigCheckBox->isChecked();
 	m_ui.ServerConfigNameComboBox->setEnabled(bEnabled);
-	m_ui.ServerConfigTempCheckBox->setEnabled(bEnabled);
 
 	m_ui.AliasesEditingCheckBox->setEnabled(
 		m_ui.AliasesEnabledCheckBox->isChecked());
@@ -1173,9 +1227,13 @@ void qjackctlSetupForm::stabilizeForm (void)
 
 	m_ui.TransportButtonsCheckBox->setEnabled(
 		m_ui.LeftButtonsCheckBox->isChecked());
+	m_ui.GraphButtonCheckBox->setEnabled(
+		!m_ui.LeftButtonsCheckBox->isChecked());
 
 	changeDriverUpdate(m_ui.DriverComboBox->currentText(), false);
 
+	bValid = (bValid || m_iDirtyBuffSize > 0);
+	m_ui.DialogButtonBox->button(QDialogButtonBox::Apply)->setEnabled(bValid);
 	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
 }
 
@@ -1241,7 +1299,7 @@ void qjackctlSetupForm::symbolPostShutdownScript (void)
 
 
 // Startup script browse slot.
-void qjackctlSetupForm::browseStartupScript()
+void qjackctlSetupForm::browseStartupScript (void)
 {
 	QString sFileName = QFileDialog::getOpenFileName(
 		this,												// Parent.
@@ -1258,7 +1316,7 @@ void qjackctlSetupForm::browseStartupScript()
 
 
 // Post-startup script browse slot.
-void qjackctlSetupForm::browsePostStartupScript()
+void qjackctlSetupForm::browsePostStartupScript (void)
 {
 	QString sFileName = QFileDialog::getOpenFileName(
 		this,												// Parent.
@@ -1275,7 +1333,7 @@ void qjackctlSetupForm::browsePostStartupScript()
 
 
 // Shutdown script browse slot.
-void qjackctlSetupForm::browseShutdownScript()
+void qjackctlSetupForm::browseShutdownScript (void)
 {
 	QString sFileName = QFileDialog::getOpenFileName(
 		this,												// Parent.
@@ -1292,7 +1350,7 @@ void qjackctlSetupForm::browseShutdownScript()
 
 
 // Post-shutdown script browse slot.
-void qjackctlSetupForm::browsePostShutdownScript()
+void qjackctlSetupForm::browsePostShutdownScript (void)
 {
 	QString sFileName = QFileDialog::getOpenFileName(
 		this,												// Parent.
@@ -1309,7 +1367,7 @@ void qjackctlSetupForm::browsePostShutdownScript()
 
 
 // Active Patchbay path browse slot.
-void qjackctlSetupForm::browseActivePatchbayPath()
+void qjackctlSetupForm::browseActivePatchbayPath (void)
 {
 	QString sFileName = QFileDialog::getOpenFileName(
 		this,											// Parent.
@@ -1327,7 +1385,7 @@ void qjackctlSetupForm::browseActivePatchbayPath()
 
 
 // Messages log path browse slot.
-void qjackctlSetupForm::browseMessagesLogPath()
+void qjackctlSetupForm::browseMessagesLogPath (void)
 {
 	QString sFileName = QFileDialog::getSaveFileName(
 		this,											// Parent.
@@ -1345,7 +1403,7 @@ void qjackctlSetupForm::browseMessagesLogPath()
 
 
 // The display font 1 (big time) selection dialog.
-void qjackctlSetupForm::chooseDisplayFont1()
+void qjackctlSetupForm::chooseDisplayFont1 (void)
 {
 	bool  bOk  = false;
 	QFont font = QFontDialog::getFont(&bOk,
@@ -1360,7 +1418,7 @@ void qjackctlSetupForm::chooseDisplayFont1()
 
 
 // The display font 2 (normal time et al.) selection dialog.
-void qjackctlSetupForm::chooseDisplayFont2()
+void qjackctlSetupForm::chooseDisplayFont2 (void)
 {
 	bool  bOk  = false;
 	QFont font = QFontDialog::getFont(&bOk,
@@ -1421,6 +1479,17 @@ void qjackctlSetupForm::chooseConnectionsFont (void)
 }
 
 
+// Brag about any buffer-size (frames/period) changes...
+void qjackctlSetupForm::buffSizeChanged (void)
+{
+	if (m_iDirtySetup > 0)
+		return;
+
+	++m_iDirtyBuffSize;
+	stabilizeForm();
+}
+
+
 // Mark that some server preset settings have changed.
 void qjackctlSetupForm::settingsChanged (void)
 {
@@ -1431,25 +1500,44 @@ void qjackctlSetupForm::settingsChanged (void)
 	stabilizeForm();
 }
 
+
 // Mark that some program options have changed.
 void qjackctlSetupForm::optionsChanged (void)
 {
 	if (m_iDirtySetup > 0)
 		return;
 
-	m_iDirtyOptions++;
+	++m_iDirtyOptions;
 	stabilizeForm();
 }
 
 
-// Accept settings (OK button slot).
-void qjackctlSetupForm::accept (void)
+// Apply settings (Apply button slot).
+void qjackctlSetupForm::apply (void)
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
-	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0) {
+	if (m_iDirtySettings > 0 || m_iDirtyPreset > 0) {
+		// Save current preset selection.
+		m_pSetup->sDefPreset = m_ui.PresetComboBox->currentText();
+		// Always save current settings...
+		savePreset(m_pSetup->sDefPreset);
+	}
+	else
+	if (m_iDirtyBuffSize > 0) {
+		// Change JACK buffer size immediately...
+		if (!pMainForm->resetBuffSize(jack_nframes_t(
+				m_ui.FramesComboBox->currentText().toUInt()))) {
+			// Make up a settings change instead...
+			++m_iDirtySettings;
+		}
+		// We're not dirty anymore...
+		m_iDirtyBuffSize = 0;
+	}
+
+	if (m_iDirtyOptions > 0) {
 		// To track down deferred or immediate changes.
 		const bool    bOldMessagesLog         = m_pSetup->bMessagesLog;
 		const QString sOldMessagesLogPath     = m_pSetup->sMessagesLogPath;
@@ -1461,8 +1549,6 @@ void qjackctlSetupForm::accept (void)
 		const int     iOldJackClientPortAlias = m_pSetup->iJackClientPortAlias;
 		const bool    bOldJackClientPortMetadata = m_pSetup->bJackClientPortMetadata;
 		const int     iOldTimeDisplay         = m_pSetup->iTimeDisplay;
-		const int     iOldTimeFormat          = m_pSetup->iTimeFormat;
-		const bool    bOldDisplayEffect       = m_pSetup->bDisplayEffect;
 		const bool    bOldActivePatchbay      = m_pSetup->bActivePatchbay;
 		const QString sOldActivePatchbayPath  = m_pSetup->sActivePatchbayPath;
 		const bool    bOldStdoutCapture       = m_pSetup->bStdoutCapture;
@@ -1472,21 +1558,19 @@ void qjackctlSetupForm::accept (void)
 	#endif
 		const int     bOldMessagesLimit       = m_pSetup->bMessagesLimit;
 		const int     iOldMessagesLimitLines  = m_pSetup->iMessagesLimitLines;
-		const bool    bOldBezierLines         = m_pSetup->bBezierLines;
 		const bool    bOldAlsaSeqEnabled      = m_pSetup->bAlsaSeqEnabled;
+	#ifdef CONFIG_DBUS
 		const bool    bOldDBusEnabled         = m_pSetup->bDBusEnabled;
 		const bool    bOldJackDBusEnabled     = m_pSetup->bJackDBusEnabled;
+	#endif
 		const bool    bOldAliasesEnabled      = m_pSetup->bAliasesEnabled;
 		const bool    bOldAliasesEditing      = m_pSetup->bAliasesEditing;
 		const bool    bOldLeftButtons         = m_pSetup->bLeftButtons;
 		const bool    bOldRightButtons        = m_pSetup->bRightButtons;
 		const bool    bOldTransportButtons    = m_pSetup->bTransportButtons;
 		const bool    bOldTextLabels          = m_pSetup->bTextLabels;
+		const bool    bOldGraphButton         = m_pSetup->bGraphButton;
 		const int     iOldBaseFontSize        = m_pSetup->iBaseFontSize;
-		// Save current preset selection.
-		m_pSetup->sDefPreset = m_ui.PresetComboBox->currentText();
-		// Always save current settings...
-		savePreset(m_pSetup->sDefPreset);
 		// Save Options...
 		m_pSetup->bStartupScript           = m_ui.StartupScriptCheckBox->isChecked();
 		m_pSetup->sStartupScriptShell      = m_ui.StartupScriptShellComboBox->currentText();
@@ -1504,16 +1588,13 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bQueryDisconnect         = m_ui.QueryDisconnectCheckBox->isChecked();
 		m_pSetup->bMessagesLog             = m_ui.MessagesLogCheckBox->isChecked();
 		m_pSetup->sMessagesLogPath         = m_ui.MessagesLogPathComboBox->currentText();
-		m_pSetup->bBezierLines             = m_ui.BezierLinesCheckBox->isChecked();
 		// Save Defaults...
 		m_pSetup->iTimeDisplay             = m_pTimeDisplayButtonGroup->checkedId();
-		m_pSetup->iTimeFormat              = m_ui.TimeFormatComboBox->currentIndex();
 		m_pSetup->sMessagesFont            = m_ui.MessagesFontTextLabel->font().toString();
 		m_pSetup->bMessagesLimit           = m_ui.MessagesLimitCheckBox->isChecked();
 		m_pSetup->iMessagesLimitLines      = m_ui.MessagesLimitLinesComboBox->currentText().toInt();
 		m_pSetup->sDisplayFont1            = m_ui.DisplayFont1TextLabel->font().toString();
 		m_pSetup->sDisplayFont2            = m_ui.DisplayFont2TextLabel->font().toString();
-		m_pSetup->bDisplayEffect           = m_ui.DisplayEffectCheckBox->isChecked();
 		m_pSetup->bDisplayBlink            = m_ui.DisplayBlinkCheckBox->isChecked();
 		m_pSetup->iJackClientPortAlias     = m_ui.JackClientPortAliasComboBox->currentIndex();
 		m_pSetup->bJackClientPortMetadata  = m_ui.JackClientPortMetadataCheckBox->isChecked();
@@ -1532,28 +1613,24 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bSingleton               = m_ui.SingletonCheckBox->isChecked();
 		m_pSetup->bServerConfig            = m_ui.ServerConfigCheckBox->isChecked();
 		m_pSetup->sServerConfigName        = m_ui.ServerConfigNameComboBox->currentText();
-		m_pSetup->bServerConfigTemp        = m_ui.ServerConfigTempCheckBox->isChecked();
 		m_pSetup->bAlsaSeqEnabled          = m_ui.AlsaSeqEnabledCheckBox->isChecked();
+	#if CONFIG_DBUS
 		m_pSetup->bDBusEnabled             = m_ui.DBusEnabledCheckBox->isChecked();
 		m_pSetup->bJackDBusEnabled         = m_ui.JackDBusEnabledCheckBox->isChecked();
+	#endif
 		m_pSetup->bAliasesEnabled          = m_ui.AliasesEnabledCheckBox->isChecked();
 		m_pSetup->bAliasesEditing          = m_ui.AliasesEditingCheckBox->isChecked();
 		m_pSetup->bLeftButtons             = !m_ui.LeftButtonsCheckBox->isChecked();
 		m_pSetup->bRightButtons            = !m_ui.RightButtonsCheckBox->isChecked();
 		m_pSetup->bTransportButtons        = !m_ui.TransportButtonsCheckBox->isChecked();
 		m_pSetup->bTextLabels              = !m_ui.TextLabelsCheckBox->isChecked();
+		m_pSetup->bGraphButton             = m_ui.GraphButtonCheckBox->isChecked();
 		m_pSetup->iBaseFontSize            = m_ui.BaseFontSizeComboBox->currentText().toInt();
 		// Check wheather something immediate has changed.
 		if (( bOldMessagesLog && !m_pSetup->bMessagesLog) ||
 			(!bOldMessagesLog &&  m_pSetup->bMessagesLog) ||
 			(sOldMessagesLogPath != m_pSetup->sMessagesLogPath))
 			pMainForm->updateMessagesLogging();
-		if (( bOldBezierLines && !m_pSetup->bBezierLines) ||
-			(!bOldBezierLines &&  m_pSetup->bBezierLines))
-			pMainForm->updateBezierLines();
-		if (( bOldDisplayEffect && !m_pSetup->bDisplayEffect) ||
-			(!bOldDisplayEffect &&  m_pSetup->bDisplayEffect))
-			pMainForm->updateDisplayEffect();
 		if (iOldJackClientPortAlias != m_pSetup->iJackClientPortAlias)
 			pMainForm->updateJackClientPortAlias();
 		if (( bOldJackClientPortMetadata && !m_pSetup->bJackClientPortMetadata) ||
@@ -1574,8 +1651,6 @@ void qjackctlSetupForm::accept (void)
 			pMainForm->updateTimeDisplayFonts();
 		if (iOldTimeDisplay != m_pSetup->iTimeDisplay)
 			pMainForm->updateTimeDisplayToolTips();
-		if (iOldTimeFormat != m_pSetup->iTimeFormat)
-			pMainForm->updateTimeFormat();
 		if ((!bOldActivePatchbay && m_pSetup->bActivePatchbay) ||
 			(sOldActivePatchbayPath != m_pSetup->sActivePatchbayPath))
 			pMainForm->updateActivePatchbay();
@@ -1595,24 +1670,29 @@ void qjackctlSetupForm::accept (void)
 			(!bOldRightButtons &&  m_pSetup->bRightButtons) ||
 			( bOldTransportButtons && !m_pSetup->bTransportButtons) ||
 			(!bOldTransportButtons &&  m_pSetup->bTransportButtons) ||
-			( bOldTextLabels && !m_pSetup->bTextLabels) ||
-			(!bOldTextLabels &&  m_pSetup->bTextLabels))
+			( bOldTextLabels   && !m_pSetup->bTextLabels)   ||
+			(!bOldTextLabels   &&  m_pSetup->bTextLabels)   ||
+			( bOldGraphButton  && !m_pSetup->bGraphButton)  ||
+			(!bOldGraphButton  &&  m_pSetup->bGraphButton))
 			pMainForm->updateButtons();
+	#ifdef CONFIG_DBUS
+		if (( bOldJackDBusEnabled && !m_pSetup->bJackDBusEnabled) ||
+			(!bOldJackDBusEnabled &&  m_pSetup->bJackDBusEnabled))
+			pMainForm->updateJackDBus();
+	#endif
 		// Warn if something will be only effective on next run.
-		if (( bOldStdoutCapture   && !m_pSetup->bStdoutCapture)   ||
-			(!bOldStdoutCapture   &&  m_pSetup->bStdoutCapture)   ||
-			( bOldKeepOnTop       && !m_pSetup->bKeepOnTop)       ||
-			(!bOldKeepOnTop       &&  m_pSetup->bKeepOnTop)       ||
-			( bOldAlsaSeqEnabled  && !m_pSetup->bAlsaSeqEnabled)  ||
-			(!bOldAlsaSeqEnabled  &&  m_pSetup->bAlsaSeqEnabled)  ||
-			( bOldDBusEnabled     && !m_pSetup->bDBusEnabled)     ||
-			(!bOldDBusEnabled     &&  m_pSetup->bDBusEnabled)     ||
-			( bOldJackDBusEnabled && !m_pSetup->bJackDBusEnabled) ||
-			(!bOldJackDBusEnabled &&  m_pSetup->bJackDBusEnabled) ||
+		if (( bOldStdoutCapture   && !m_pSetup->bStdoutCapture)  ||
+			(!bOldStdoutCapture   &&  m_pSetup->bStdoutCapture)  ||
+			( bOldKeepOnTop       && !m_pSetup->bKeepOnTop)      ||
+			(!bOldKeepOnTop       &&  m_pSetup->bKeepOnTop)      ||
+			( bOldAlsaSeqEnabled  && !m_pSetup->bAlsaSeqEnabled) ||
+			(!bOldAlsaSeqEnabled  &&  m_pSetup->bAlsaSeqEnabled) ||
+		#ifdef CONFIG_DBUS
+			( bOldDBusEnabled     && !m_pSetup->bDBusEnabled)    ||
+			(!bOldDBusEnabled     &&  m_pSetup->bDBusEnabled)    ||
+		#endif
 			(iOldBaseFontSize     !=  m_pSetup->iBaseFontSize))
 			pMainForm->showDirtySetupWarning();
-		// If server is currently running, warn user...
-		pMainForm->showDirtySettingsWarning();
 	}
 
 	// Save combobox history...
@@ -1631,11 +1711,30 @@ void qjackctlSetupForm::accept (void)
 	// Save/commit to disk.
 	m_pSetup->saveSetup();
 
-	// Reset dirty flags.
+	// If server is currently running, warn user...
+	if (m_iDirtySettings > 0 || m_iDirtyPreset > 0) {
+		// Maybe whether to restart the server, who knows?
+		pMainForm->showDirtySettingsWarning();
+		// Maybe something changed on the way up?...
+		m_ui.QueryShutdownCheckBox->setChecked(m_pSetup->bQueryShutdown);
+	}
+
+	// Reset all dirty flags...
+	m_iDirtyPreset = 0;
 	m_iDirtySettings = 0;
 	m_iDirtyOptions = 0;
 
+	// Make it stable anyway...
+	stabilizeForm();
+}
+
+
+// Accept settings (OK button slot).
+void qjackctlSetupForm::accept (void)
+{
 	// Just go with dialog acceptance.
+	apply();
+
 	QDialog::accept();
 }
 
@@ -1648,6 +1747,29 @@ void qjackctlSetupForm::reject (void)
 }
 
 
+// Dialog bos button slot.
+void qjackctlSetupForm::buttonClicked ( QAbstractButton *pButton )
+{
+#ifdef CONFIG_DEBUG
+	qDebug("qjackctlSetupForm::buttonClicked(%p)", pButton);
+#endif
+
+	switch (m_ui.DialogButtonBox->buttonRole(pButton)) {
+	case QDialogButtonBox::AcceptRole:
+		accept();
+		break;
+	case QDialogButtonBox::ApplyRole:
+		apply();
+		break;
+	case QDialogButtonBox::RejectRole:
+		reject();
+		// Fall-thru...
+	default:
+		break;
+	}
+}
+
+
 // Check whether we're clear to close.
 bool qjackctlSetupForm::queryClose (void)
 {
@@ -1655,7 +1777,7 @@ bool qjackctlSetupForm::queryClose (void)
 
 	// Check if there's any pending changes...
 	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0) {
-		switch (QMessageBox::warning(this,
+		switch (QMessageBox::warning(isVisible() ? this : parentWidget(),
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
