@@ -1,7 +1,7 @@
 // qjackctlSetupForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,8 +26,10 @@
 
 // Forward declarations.
 class qjackctlSetup;
+class qjackctlPreset;
 
 class QButtonGroup;
+class QAbstractButton;
 
 
 //----------------------------------------------------------------------------
@@ -45,6 +47,7 @@ public:
 	~qjackctlSetupForm();
 
 	void setup(qjackctlSetup *pSetup);
+	void updateCurrentPreset(const qjackctlPreset& preset);
 	void updateCurrentPreset();
 	bool queryClose();
 
@@ -75,18 +78,27 @@ protected slots:
 	void chooseMessagesFont();
 	void chooseConnectionsFont();
 
+	void buffSizeChanged();
+
 	void settingsChanged();
 	void optionsChanged();
 
+	void apply();
+
 	void accept();
 	void reject();
 
+	void buttonClicked(QAbstractButton *);
+
 protected:
 
 	// A combo-box text item setter helper.
 	void setComboBoxCurrentText (
 		QComboBox *pComboBox, const QString& sText ) const;
 
+	void setCurrentPreset(const qjackctlPreset& preset);
+	bool getCurrentPreset(qjackctlPreset& preset);
+
 	void changePreset(const QString& sPreset);
 	bool savePreset(const QString& sPreset);
 	bool deletePreset(const QString& sPreset);
@@ -116,6 +128,8 @@ private:
 	QButtonGroup *m_pTimeDisplayButtonGroup;
 
 	int m_iDirtySetup;
+	int m_iDirtyPreset;
+	int m_iDirtyBuffSize;
 	int m_iDirtySettings;
 	int m_iDirtyOptions;
 
